package com.ruoyi.web.controller.asking;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.sooka.jnb.asking.domain.JnbAnswer;
import com.sooka.jnb.asking.service.IJnbAnswerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 问答列-答案Controller
 *
 * @author ruoyi
 * @date 2024-03-13
 */
@RestController
@RequestMapping("/asking/answer")
public class JnbAnswerController extends BaseController {
    @Autowired
    private IJnbAnswerService jnbAnswerService;

    /**
     * 查询问答列-答案列表
     */
    @PreAuthorize("@ss.hasPermi('system:answer:list')")
    @GetMapping("/list")
    public TableDataInfo list(JnbAnswer jnbAnswer) {
        startPage();
        List<JnbAnswer> list = jnbAnswerService.selectJnbAnswerList(jnbAnswer);
        return getDataTable(list);
    }

    /**
     * 导出问答列-答案列表
     */
    @PreAuthorize("@ss.hasPermi('system:answer:export')")
    @Log(title = "问答列-答案", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, JnbAnswer jnbAnswer) {
        List<JnbAnswer> list = jnbAnswerService.selectJnbAnswerList(jnbAnswer);
        ExcelUtil<JnbAnswer> util = new ExcelUtil<JnbAnswer>(JnbAnswer.class);
        util.exportExcel(response, list, "问答列-答案数据");
    }

    /**
     * 获取问答列-答案详细信息
     */
    @PreAuthorize("@ss.hasPermi('system:answer:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return success(jnbAnswerService.selectJnbAnswerById(id));
    }

    /**
     * 新增问答列-答案
     */
    @PreAuthorize("@ss.hasPermi('system:answer:add')")
    @Log(title = "问答列-答案", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody JnbAnswer jnbAnswer) {
        return toAjax(jnbAnswerService.insertJnbAnswer(jnbAnswer));
    }

    /**
     * 修改问答列-答案
     */
    @PreAuthorize("@ss.hasPermi('system:answer:edit')")
    @Log(title = "问答列-答案", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody JnbAnswer jnbAnswer) {
        return toAjax(jnbAnswerService.updateJnbAnswer(jnbAnswer));
    }

    /**
     * 删除问答列-答案
     */
    @PreAuthorize("@ss.hasPermi('system:answer:remove')")
    @Log(title = "问答列-答案", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(jnbAnswerService.deleteJnbAnswerByIds(ids));
    }

    /*
    * 小程序-添加答案
    *
    * @author 韩福成
    * @date 2024/3/13 14:27
    */
    @PostMapping("/addAnswer")
    public AjaxResult addAnswer(@RequestBody JnbAnswer jnbAnswer) {
        return toAjax(jnbAnswerService.addAnswer(jnbAnswer));
    }

    /*
    * 小程序-答案采纳
    *
    * @author 韩福成
    * @date 2024/3/13 15:00
    */
    @GetMapping("/adoptAnswer")
    public AjaxResult adoptAnswer(JnbAnswer jnbAnswer) {
        return toAjax(jnbAnswerService.adoptAnswer(jnbAnswer));
    }
}
