package com.ruoyi.web.controller.asking;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.sooka.jnb.asking.domain.JnbQuestionType;
import com.sooka.jnb.asking.service.IJnbQuestionTypeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 类型配置Controller
 *
 * @author 韩福成
 * @date 2024-03-01
 */
@RestController
@RequestMapping("/JnbQuestionType/type")
public class JnbAskTypeController extends BaseController {
    @Autowired
    private IJnbQuestionTypeService jnbQuestionTypeService;

    /**
     * 查询类型配置列表
     */
    @PreAuthorize("@ss.hasPermi('JnbQuestionType:type:list')")
    @GetMapping("/list")
    public TableDataInfo list(JnbQuestionType jnbQuestionType) {
        startPage();
        List<JnbQuestionType> list = jnbQuestionTypeService.selectJnbQuestionTypeList(jnbQuestionType);
        return getDataTable(list);
    }

    /**
     * 导出类型配置列表
     */
    @PreAuthorize("@ss.hasPermi('JnbQuestionType:type:export')")
    @Log(title = "类型配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, JnbQuestionType jnbQuestionType) {
        List<JnbQuestionType> list = jnbQuestionTypeService.selectJnbQuestionTypeList(jnbQuestionType);
        ExcelUtil<JnbQuestionType> util = new ExcelUtil<JnbQuestionType>(JnbQuestionType.class);
        util.exportExcel(response, list, "类型配置数据");
    }

    /**
     * 获取类型配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('JnbQuestionType:type:query')")
    @GetMapping(value = "/{id}")
    public R getInfo(@PathVariable("id") String id) {
        return R.ok(jnbQuestionTypeService.selectJnbQuestionTypeById(id));
    }

    /**
     * 新增类型配置
     */
    @PreAuthorize("@ss.hasPermi('JnbQuestionType:type:add')")
    @Log(title = "类型配置", businessType = BusinessType.INSERT)
    @PostMapping
    public R add(@RequestBody JnbQuestionType jnbQuestionType) {
        List<JnbQuestionType> jnbQuestionTypes = jnbQuestionTypeService.selectJnbQuestionByType(jnbQuestionType);
        if (StringUtils.isNotEmpty(jnbQuestionTypes)){
            return R.fail("类型名称已存在");
        }
        return R.ok(jnbQuestionTypeService.insertJnbQuestionType(jnbQuestionType));
    }

    /**
     * 修改类型配置
     */
    @PreAuthorize("@ss.hasPermi('JnbQuestionType:type:edit')")
    @Log(title = "类型配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public R edit(@RequestBody JnbQuestionType jnbQuestionType) {
        List<JnbQuestionType> jnbQuestionTypes = jnbQuestionTypeService.selectJnbQuestionByType(jnbQuestionType);
        if (StringUtils.isNotEmpty(jnbQuestionTypes)){
            return R.fail("类型名称已存在");
        }
        return R.ok(jnbQuestionTypeService.updateJnbQuestionType(jnbQuestionType));
    }

    /*
    * 修改是否展示
    *
    * @author 韩福成
    * @date 2024/3/14 10:15
    */
    @PutMapping("/updateAskType")
    public R updataType(@RequestBody JnbQuestionType jnbQuestionType) {
        return R.ok(jnbQuestionTypeService.updataType(jnbQuestionType));
    }

    /**
     * 删除类型配置
     */
    @PreAuthorize("@ss.hasPermi('JnbQuestionType:type:remove')")
    @Log(title = "类型配置", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public R remove(@PathVariable String[] ids) {
        return R.ok(jnbQuestionTypeService.deleteJnbQuestionTypeByIds(ids));
    }

    /*
    * 小程序-查询类型列表
    *
    * @author 韩福成
    * @date 2024/3/4 10:31
    */
    @GetMapping("/typeList")
    public TableDataInfo typeList(JnbQuestionType jnbQuestionType) {
        startPage();
        jnbQuestionType.setWhetherShow("Y");
        List<JnbQuestionType> list = jnbQuestionTypeService.selectJnbQuestionTypeList(jnbQuestionType);
        return getDataTable(list);
    }
}
