package com.ruoyi.web.controller.asking;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.sooka.jnb.asking.domain.JnbQuestion;
import com.sooka.jnb.asking.domain.JnbQuestionType;
import com.sooka.jnb.asking.service.IJnbQuestionService;
import com.sooka.jnb.asking.service.IJnbQuestionTypeService;
import com.sooka.jnb.my.domain.ScoreOperate;
import com.sooka.jnb.my.service.IScoreService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 问答列-问题Controller
 *
 * @author 韩福成
 * @date 2024-03-11
 */
@RestController
@RequestMapping("/asking/question")
public class JnbQuestionController extends BaseController {
    @Autowired
    private IJnbQuestionService jnbQuestionService;

    @Autowired
    private IJnbQuestionTypeService jnbQuestionTypeService;

    /**
     * 查询问答列-问题列表
     */
    @PreAuthorize("@ss.hasPermi('asking:question:list')")
    @GetMapping("/list")
    public TableDataInfo list(JnbQuestion jnbQuestion) {
        startPage();
        List<JnbQuestion> list = jnbQuestionService.selectJnbQuestionList(jnbQuestion);
        return getDataTable(list);
    }

    /**
     * 导出问答列-问题列表
     */
    @PreAuthorize("@ss.hasPermi('asking:question:export')")
    @Log(title = "导出问答列", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, JnbQuestion jnbQuestion) {
        List<JnbQuestion> list = jnbQuestionService.selectJnbQuestionList(jnbQuestion);
        ExcelUtil<JnbQuestion> util = new ExcelUtil<JnbQuestion>(JnbQuestion.class);
        util.exportExcel(response, list, "问答列-问题数据");
    }

    /**
     * 获取问答列-问题详细信息
     */
    @PreAuthorize("@ss.hasPermi('asking:question:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return success(jnbQuestionService.selectJnbQuestionById(id));
    }

    /**
     * 新增问答列-问题
     */
    @PreAuthorize("@ss.hasPermi('asking:question:add')")
    @Log(title = "新增问答列", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody JnbQuestion jnbQuestion) {
        return toAjax(jnbQuestionService.insertJnbQuestion(jnbQuestion));
    }

    /**
     * 修改问答列-问题
     */
    @PreAuthorize("@ss.hasPermi('asking:question:edit')")
    @Log(title = "修改问答列", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody JnbQuestion jnbQuestion) {
        return toAjax(jnbQuestionService.updateJnbQuestion(jnbQuestion));
    }

    /*
    * 修改是否展示
    *
    * @author 韩福成
    * @date 2024/3/14 10:21
    */
    @PutMapping("/updateWhetherShow")
    public R updateWhetherShow(@RequestBody JnbQuestion jnbQuestion) {
        return R.ok(jnbQuestionService.updateWhetherShow(jnbQuestion));
    }

    /**
     * 删除问答列-问题
     */
    @PreAuthorize("@ss.hasPermi('asking:question:remove')")
    @Log(title = "删除问答列", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(jnbQuestionService.deleteJnbQuestionByIds(ids));
    }

    /*
    * 审核问题
    *
    * @author 韩福成
    * @date 2024/3/11 10:20
    */
    @PreAuthorize("@ss.hasPermi('asking:question:examine')")
    @Log(title = "审核问题", businessType = BusinessType.UPDATE)
    @PutMapping("/through")
    public AjaxResult through(@RequestBody JnbQuestion jnbQuestion) {
        return toAjax(jnbQuestionService.through(jnbQuestion));
    }

    /*
    * 查询类型配置列表
    *
    * @author 韩福成
    * @date 2024/3/11 10:44
    */
    @GetMapping("/typeList")
    public R typeList(JnbQuestionType jnbQuestionType) {
        return R.ok(jnbQuestionTypeService.selectJnbQuestionTypeList(jnbQuestionType));
    }

    /*
    * 小程序-获取热门问答列表
    *
    * @author 韩福成
    * @date 2024/3/11 11:21
    */
    @GetMapping("/getHotQuestionList")
    public TableDataInfo getHotQuestionList(JnbQuestion jnbQuestion) {
        startPage();
        List<JnbQuestion> list = jnbQuestionService.getHotQuestionList(jnbQuestion);
        return getDataTable(list);
    }

    /*
    * 小程序-新增问题
    *
    * @author 韩福成
    * @date 2024/3/12 10:32
    */
    @Log(title = "新增问题", businessType = BusinessType.INSERT)
    @PostMapping("addQuestion")
    public AjaxResult addQuestion(@RequestBody JnbQuestion jnbQuestion) {
        return toAjax(jnbQuestionService.insertJnbQuestion(jnbQuestion));
    }

    /*
    * 小程序-按类型查询全部列表问题
    *
    * @author 韩福成
    * @date 2024/3/12 13:02
    */
    @GetMapping("/getAllQuestionByType")
    public TableDataInfo getQuestionByType(JnbQuestion jnbQuestion) {
        startPage();
        List<JnbQuestion> list = jnbQuestionService.getQuestionByType(jnbQuestion);
        return getDataTable(list);
    }

    /*
    * 小程序-按类型查询精彩回答问题列表
    *
    * @author 韩福成
    * @date 2024/3/12 15:48
    */
    @GetMapping("/getExcitingAnswersList")
    public TableDataInfo getExcitingAnswersList(JnbQuestion jnbQuestion) {
        startPage();
        List<JnbQuestion> list = jnbQuestionService.getExcitingAnswersList(jnbQuestion);
        return getDataTable(list);
    }

    /*
    *小程序-按类型查询最多悬赏问题列表
    *
    * @author 韩福成
    * @date 2024/3/12 15:49
    */
    @GetMapping("/getMaxScoreList")
    public TableDataInfo getMaxScoreList(JnbQuestion jnbQuestion) {
        startPage();
        List<JnbQuestion> list = jnbQuestionService.getMaxScoreList(jnbQuestion);
        return getDataTable(list);
    }

    /*
    * 小程序-获取问题详情
    *
    * @author 韩福成
    * @date 2024/3/13 8:54
    */
    @GetMapping(value = "/getDetailById")
    public AjaxResult getDetailById(JnbQuestion jnbQuestion) {
        return success(jnbQuestionService.getDetailById(jnbQuestion.getId()));
    }

}
