package com.ruoyi.web.controller.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.sooka.jnb.cooperative.domain.Cooperative;
import com.sooka.jnb.cooperative.service.ICooperativeService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 供销合作社Controller
 * 
 * @author ruoyi
 * @date 2024-03-01
 */
@RestController
@RequestMapping("/high/server/cooperative")
public class CooperativeController extends BaseController
{
    @Autowired
    private ICooperativeService cooperativeService;

    /**
     * 查询供销合作社列表
     */
//    @PreAuthorize("@ss.hasPermi('highfrequency:cooperative:list')")
    @GetMapping("/list")
    public TableDataInfo list(Cooperative cooperative)
    {
        startPage();
        List<Cooperative> list = cooperativeService.selectCooperativeList(cooperative);
        return getDataTable(list);
    }

    /**
     * 导出供销合作社列表
     */
    @PreAuthorize("@ss.hasPermi('highfrequency:cooperative:export')")
    @Log(title = "供销合作社", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Cooperative cooperative)
    {
        List<Cooperative> list = cooperativeService.selectCooperativeList(cooperative);
        ExcelUtil<Cooperative> util = new ExcelUtil<Cooperative>(Cooperative.class);
        util.exportExcel(response, list, "供销合作社数据");
    }

    /**
     * 获取供销合作社详细信息
     */
//    @PreAuthorize("@ss.hasPermi('highfrequency:cooperative:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(cooperativeService.selectCooperativeById(id));
    }

    /**
     * 新增供销合作社
     */
//    @PreAuthorize("@ss.hasPermi('highfrequency:cooperative:add')")
    @Log(title = "供销合作社", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Cooperative cooperative)
    {
        return toAjax(cooperativeService.insertCooperative(cooperative));
    }

    /**
     * 修改供销合作社
     */
    @PreAuthorize("@ss.hasPermi('highfrequency:cooperative:edit')")
    @Log(title = "供销合作社", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Cooperative cooperative)
    {
        return toAjax(cooperativeService.updateCooperative(cooperative));
    }

    /**
     * 删除供销合作社
     */
    @PreAuthorize("@ss.hasPermi('highfrequency:cooperative:remove')")
    @Log(title = "供销合作社", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(cooperativeService.deleteCooperativeByIds(ids));
    }
}
