package com.ruoyi.web.controller.handleAffairs;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.sooka.jnb.handleAffairs.domain.GridType;
import com.sooka.jnb.handleAffairs.service.IGridTypeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

@RestController
@RequestMapping("/jnb/gridType")
public class GridTypeController extends BaseController {

    @Autowired
    private IGridTypeService gridTypeService;

    /**
     * 查询网格类型配置列表
     */
    @GetMapping("/list")
    public TableDataInfo list(GridType GridType)
    {
        startPage();
        List<GridType> list = gridTypeService.selectGridTypeList(GridType);
        return getDataTable(list);
    }

    /**
     * 获取网格类型配置详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(gridTypeService.selectGridTypeById(id));
    }

    /**
     * 新增网格类型配置
     */
    @Log(title = "网格类型配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody GridType GridType)
    {
        return toAjax(gridTypeService.insertGridType(GridType));
    }

    /**
     * 修改网格类型配置
     */
    @Log(title = "网格类型配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody GridType GridType)
    {
        return toAjax(gridTypeService.updateGridType(GridType));
    }

    /**
     * 删除网格类型配置
     */
    @Log(title = "网格类型配置", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(gridTypeService.deleteGridTypeByIds(ids));
    }

    /**
     * 导出网格类型配置列表
     */
    @Log(title = "网格类型配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, GridType GridType)
    {
        List<GridType> list = gridTypeService.selectGridTypeList(GridType);
        ExcelUtil<GridType> util = new ExcelUtil<GridType>(GridType.class);
        util.exportExcel(response, list, "网格类型配置数据");
    }
}
