package com.ruoyi.web.controller.handleAffairs;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.sooka.jnb.handleAffairs.domain.TopicType;
import com.sooka.jnb.handleAffairs.service.ITopicTypeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;

import java.util.List;

import static com.ruoyi.common.utils.PageUtils.startPage;

/**
 * 主题类型配置Controller
 *
 * @author lidongyu
 * @date 2024-03-01
 */
@RestController
@RequestMapping("/jnb/topicType")
public class TopicTypeController extends BaseController {
    @Autowired
    private ITopicTypeService topicTypeService;

    /**
     * 查询主题类型配置列表
     */
    @GetMapping("/list")
    public TableDataInfo list(TopicType topicType)
    {
        startPage();
        List<TopicType> list = topicTypeService.selectTopicTypeList(topicType);
        return getDataTable(list);
    }
    @GetMapping("/listAll")
    public AjaxResult listAll(TopicType topicType)
    {
        return success(topicTypeService.selectTopicTypeList(topicType));
    }
    /**
     * 导出主题类型配置列表
     */
    @Log(title = "主题类型配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, TopicType topicType)
    {
        List<TopicType> list = topicTypeService.selectTopicTypeList(topicType);
        ExcelUtil<TopicType> util = new ExcelUtil<TopicType>(TopicType.class);
        util.exportExcel(response, list, "主题类型配置数据");
    }

    /**
     * 获取主题类型配置详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(topicTypeService.selectTopicTypeById(id));
    }

    /**
     * 新增主题类型配置
     */
    @Log(title = "主题类型配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody TopicType topicType)
    {
        return toAjax(topicTypeService.insertTopicType(topicType));
    }

    /**
     * 修改主题类型配置
     */
    @Log(title = "主题类型配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody TopicType topicType)
    {
        return toAjax(topicTypeService.updateTopicType(topicType));
    }

    /**
     * 删除主题类型配置
     */
    @Log(title = "主题类型配置", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(topicTypeService.deleteTopicTypeByIds(ids));
    }
}
