package com.ruoyi.web.controller.highServer;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.sooka.jnb.highServer.domain.JnbHighServer;
import com.sooka.jnb.highServer.service.IJnbHighServerService;
import com.sooka.jnb.highServer.vo.JnbHighServerVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 高频服务Controller
 *
 * @author ruoyi
 * @date 2024-03-01
 */
@RestController
@RequestMapping("/high/server")
public class JnbHighServerController extends BaseController {

    @Autowired
    private IJnbHighServerService jnbHighServerService;

    /**
     * 查询高频服务列表
     */
    @GetMapping("/list")
    public TableDataInfo list(JnbHighServerVO jnbHighServerVO) {
        startPage();
        List<JnbHighServerVO> list = jnbHighServerService.selectJnbHighServerList(jnbHighServerVO);
        return getDataTable(list);
    }

    /**
     * 导出高频服务列表
     */
    @Log(title = "高频服务", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, JnbHighServerVO jnbHighServerVO) {
        List<JnbHighServerVO> list = jnbHighServerService.selectJnbHighServerList(jnbHighServerVO);
        ExcelUtil<JnbHighServerVO> util = new ExcelUtil<JnbHighServerVO>(JnbHighServerVO.class);
        util.exportExcel(response, list, "高频服务数据");
    }

    /**
     * 获取高频服务详细信息
     */
    @GetMapping(value = "/{id}/{type}")
    public AjaxResult getInfo(@PathVariable("id") Long id,@PathVariable("type") Integer type) {
        return success(jnbHighServerService.selectJnbHighServerById(id,type));
    }

    /**
     * 新增高频服务
     */
    @Log(title = "高频服务", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody JnbHighServerVO jnbHighServerVO) {
        return toAjax(jnbHighServerService.insertJnbHighServer(jnbHighServerVO));
    }

    /**
     * 修改高频服务
     */
    @Log(title = "高频服务", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody JnbHighServerVO jnbHighServerVO) {
        return toAjax(jnbHighServerService.updateJnbHighServer(jnbHighServerVO));
    }

    /**
     * 删除高频服务
     */
    @Log(title = "高频服务", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}/{type}")
    public AjaxResult remove(@PathVariable Long[] ids,@PathVariable("type") Integer type) {
        return toAjax(jnbHighServerService.deleteJnbHighServerByIds(ids,type));
    }

    /**
     * 小程序获取直播带货列表
     */
    @GetMapping("/liveBroadcastList")
    public TableDataInfo getLiveBroadcast(JnbHighServer jnbHighServer) {
        startPage();
        List<JnbHighServerVO> list = jnbHighServerService.getLiveBroadcast(jnbHighServer);
        return getDataTable(list);
    }

    /**
     * 小程序获取直播带货详情
     */
    @GetMapping("/liveBroadcastDetails/{id}")
    public AjaxResult liveBroadcastDetails(@PathVariable Long id) {
        return success(jnbHighServerService.liveBroadcastDetails(id));
    }

    /**
     * 小程序获取生活服务列表
     */
    @GetMapping("/lifeServicesList")
    public TableDataInfo getLifeServices(JnbHighServer jnbHighServer) {
        startPage();
        List<JnbHighServerVO> list = jnbHighServerService.getLifeServices(jnbHighServer);
        return getDataTable(list);
    }

    /**
     * 小程序获取生活服务详情
     */
    @GetMapping("/lifeServicesDetails/{id}")
    public AjaxResult lifeServicesDetails(@PathVariable Long id) {
        return success(jnbHighServerService.lifeServicesDetails(id));
    }

    /**
     * 小程序获取旅游向导列表
     */
    @GetMapping("/travelGuideList")
    public TableDataInfo getTravelGuide(JnbHighServer jnbHighServer) {
        startPage();
        List<JnbHighServerVO> list = jnbHighServerService.getTravelGuide(jnbHighServer);
        return getDataTable(list);
    }

    /**
     * 小程序获取旅游向导详情
     */
    @GetMapping("/travelGuideDetails/{id}")
    public AjaxResult travelGuideDetails(@PathVariable Long id) {
        return success(jnbHighServerService.travelGuideDetails(id));
    }

    /**
     * 小程序获取心理咨询列表
     */
    @GetMapping("/psychologyList")
    public TableDataInfo getPsychology(JnbHighServer jnbHighServer) {
        startPage();
        List<JnbHighServerVO> list = jnbHighServerService.getPsychology(jnbHighServer);
        return getDataTable(list);
    }

    /**
     * 小程序获取心理咨询详情
     */
    @GetMapping("/psychologyDetails/{id}")
    public AjaxResult psychologyDetails(@PathVariable Long id) {
        return success(jnbHighServerService.psychologyDetails(id));
    }

    /**
     * 小程序获取乡村婚恋列表
     */
    @GetMapping("/loveAtVillageList")
    public TableDataInfo getLoveAtVillage(JnbHighServer jnbHighServer) {
        startPage();
        List<JnbHighServerVO> list = jnbHighServerService.getLoveAtVillage(jnbHighServer);
        return getDataTable(list);
    }

    /**
     * 小程序获取乡村婚恋详情
     */
    @GetMapping("/loveAtVillageDetails/{id}")
    public AjaxResult loveAtVillageDetails(@PathVariable Long id) {
        return success(jnbHighServerService.loveAtVillageDetails(id));
    }

    /**
     * 小程序获取法律服务列表
     */
    @GetMapping("/legalServiceList")
    public TableDataInfo getLegalService(JnbHighServer jnbHighServer) {
        startPage();
        List<JnbHighServerVO> list = jnbHighServerService.getLegalService(jnbHighServer);
        return getDataTable(list);
    }

    /**
     * 小程序获法律服务询详情
     */
    @GetMapping("/legalServiceDetails/{id}")
    public AjaxResult legalServiceDetails(@PathVariable Long id) {
        return success(jnbHighServerService.legalServiceDetails(id));
    }

    /**
     * 小程序获取金融基建列表
     */
    @GetMapping("/financialInfrastructureList")
    public TableDataInfo getFinancialInfrastructure(JnbHighServer jnbHighServer) {
        startPage();
        List<JnbHighServerVO> list = jnbHighServerService.getFinancialInfrastructure(jnbHighServer);
        return getDataTable(list);
    }

    /**
     * 小程序获金融基建询详情
     */
    @GetMapping("/financialInfrastructureDetails/{id}")
    public AjaxResult financialInfrastructureDetails(@PathVariable Long id) {
        return success(jnbHighServerService.financialInfrastructureDetails(id));
    }

    /**
     * 小程序获取线上问诊列表
     */
    @GetMapping("/inquiryList")
    public TableDataInfo getInquiry(JnbHighServer jnbHighServer) {
        startPage();
        List<JnbHighServerVO> list = jnbHighServerService.getInquiry(jnbHighServer);
        return getDataTable(list);
    }

    /**
     * 小程序获取线上问诊详情
     */
    @GetMapping("/inquiryDetails/{id}")
    public AjaxResult inquiryDetails(@PathVariable Long id) {
        return success(jnbHighServerService.inquiryDetails(id));
    }

    /**
     * 小程序获取帮扶救助列表
     */
    @GetMapping("/helpList")
    public TableDataInfo getHelp(JnbHighServer jnbHighServer) {
        startPage();
        List<JnbHighServerVO> list = jnbHighServerService.getHelp(jnbHighServer);
        return getDataTable(list);
    }

    /**
     * 小程序获取帮扶救助详情
     */
    @GetMapping("/helpDetails/{id}")
    public AjaxResult helpDetails(@PathVariable Long id) {
        return success(jnbHighServerService.helpDetails(id));
    }
}
