package com.ruoyi.web.controller.information;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.github.pagehelper.Page;
import com.sooka.jnb.information.domain.Information;
import com.sooka.jnb.information.domain.InformationUni;
import com.sooka.jnb.information.service.InformationService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 资讯Controller
 * 
 * @author ruoyi
 * @date 2024-03-01
 */
@RestController
@RequestMapping("/jnb/information")
public class InformationController extends BaseController
{
    @Autowired
    private InformationService informationService;

    /**
     * 点赞
     */
    @PostMapping("/like")
    public AjaxResult like(@RequestBody Information information){
        return toAjax(informationService.likeById(information));
    }


    /**
     * 浏览
     */
    @PostMapping("/watch")
    public AjaxResult watchById(@RequestBody Information information){
        return toAjax(informationService.watchById(information));
    }


    /**
     * 查询资讯列表
     */
//    @PreAuthorize("@ss.hasPermi('jnb:information:list')")
    @GetMapping("/list")
    public TableDataInfo list(Information information)
    {
        startPage();
        List<Information> list = informationService.selectInformationList(information);
        return getDataTable(list);
    }


    /**
     * 查询前三条-小程序
     */
//    @PreAuthorize("@ss.hasPermi('jnb:information:query')")
    @GetMapping("/listWx")
    public AjaxResult listWx(Information information)
    {
        List<InformationUni> list = informationService.selectInformationListWx(information);
        return AjaxResult.success(list);
    }

    /**
     * 查询文章列表包括置顶-小程序
     */
//    @PreAuthorize("@ss.hasPermi('jnb:information:query')")
    @GetMapping("/listWxs")
    public TableDataInfo listWxs(Information information)
    {
        startPage();
        List<Information> list = informationService.selectInformationListWxs(information);
        return getDataTable(list);
    }


    /**
     * 导出资讯列表
     */
//    @PreAuthorize("@ss.hasPermi('jnb:information:export')")
    @Log(title = "资讯导出", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, Information information)
    {
        List<Information> list = informationService.selectInformationList(information);
        ExcelUtil<Information> util = new ExcelUtil<Information>(Information.class);
        util.exportExcel(response, list, "资讯数据");
    }

    /**
     * 获取资讯详细信息
     */
//    @PreAuthorize("@ss.hasPermi('jnb:information:query')")
    @GetMapping(value = "/{id}/{type}")
    public AjaxResult getInfo(@PathVariable("id") Long id,@PathVariable("type") Integer type)
    {
        return success(informationService.selectInformationById(id,type));
    }
    /**
     * 获取资讯详细信息-小程序
     */
//    @PreAuthorize("@ss.hasPermi('jnb:information:query')")
    @GetMapping(value = "/uniApp/{id}/{type}")
    public AjaxResult getInfoUniApp(@PathVariable("id") Long id,@PathVariable("type") Integer type)
    {
        return success(informationService.selectInformationByIdgetInfoUniApp(id,type));
    }
    /**
     * 新增资讯
     */
//    @PreAuthorize("@ss.hasPermi('jnb:information:add')")
    @Log(title = "新增资讯", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody Information information)
    {
        return toAjax(informationService.insertInformationServer(information));
    }
    @Log(title = "新增资讯-小程序", businessType = BusinessType.INSERT)
    @PostMapping("/uniApp")
    public AjaxResult adduniApp(@RequestBody InformationUni information)
    {
        return toAjax(informationService.insertInformationServerUni(information));
    }
    /**
     * 修改资讯
     */
//    @PreAuthorize("@ss.hasPermi('jnb:information:edit')")
    @Log(title = "修改资讯", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody Information information)
    {
        return toAjax(informationService.updateInformation(information));
    }
    @Log(title = "修改资讯", businessType = BusinessType.UPDATE)
    @PutMapping("/uniApp")
    public AjaxResult editUniApp(@RequestBody InformationUni information)
    {
        return toAjax(informationService.updateInformationUni(information));
    }
    /**
     * 删除资讯
     */
//    @PreAuthorize("@ss.hasPermi('jnb:information:remove')")
    @Log(title = "删除资讯", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}/{type}")
    public AjaxResult remove(@PathVariable("ids") Long[] ids,@PathVariable("type") Integer type)
    {
        return toAjax(informationService.deleteInformationByIds(ids,type));
    }
}
