package com.ruoyi.web.controller.knowledge;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.sooka.jnb.knowledge.dto.JnbKnowledgeBaseDTO;
import com.sooka.jnb.knowledge.service.IJnbKnowledgeBaseService;
import com.sooka.jnb.knowledge.vo.JnbKnowledgeBaseVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 知识库Controller
 *
 * @author ruoyi
 * @date 2024-03-01
 */
@RestController
@RequestMapping("/knowledge/base")
public class JnbKnowledgeBaserController extends BaseController {

    @Autowired
    private IJnbKnowledgeBaseService jnbKnowledgeBaseService;

    /**
     * 查询知识库列表
     */
    @GetMapping("/list")
    public TableDataInfo list(JnbKnowledgeBaseVO jnbKnowledgeBaseVO) {
        startPage();
        List<JnbKnowledgeBaseVO> list = jnbKnowledgeBaseService.selectJnbKnowledgeBaseList(jnbKnowledgeBaseVO);
        return getDataTable(list);
    }

    /**
     * 导出知识库列表
     */
    @Log(title = "知识库", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, JnbKnowledgeBaseVO jnbKnowledgeBaseVO) {
        List<JnbKnowledgeBaseVO> list = jnbKnowledgeBaseService.selectJnbKnowledgeBaseList(jnbKnowledgeBaseVO);
        ExcelUtil<JnbKnowledgeBaseVO> util = new ExcelUtil<JnbKnowledgeBaseVO>(JnbKnowledgeBaseVO.class);
        util.exportExcel(response, list, "知识库数据");
    }

    /**
     * 获取知识库详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(jnbKnowledgeBaseService.selectJnbKnowledgeBaseById(id));
    }

    /**
     * 新增知识库
     */
    @Log(title = "知识库", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody JnbKnowledgeBaseVO jnbKnowledgeBaseVO) {
        return toAjax(jnbKnowledgeBaseService.insertJnbKnowledgeBase(jnbKnowledgeBaseVO));
    }

    /**
     * 修改知识库
     */
    @Log(title = "知识库", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody JnbKnowledgeBaseVO jnbKnowledgeBaseVO) {
        return toAjax(jnbKnowledgeBaseService.updateJnbKnowledgeBase(jnbKnowledgeBaseVO));
    }

    /**
     * 删除知识库
     */
    @Log(title = "知识库", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids) {
        return toAjax(jnbKnowledgeBaseService.deleteJnbKnowledgeBaseByIds(ids));
    }

    /**
     * 修改是否热门
     */
    @Log(title = "修改是否热门", businessType = BusinessType.UPDATE)
    @PutMapping("/updateIsPopular")
    public AjaxResult updateIsPopular(@RequestBody JnbKnowledgeBaseDTO JnbKnowledgeBaseDTO) {
        return toAjax(jnbKnowledgeBaseService.updateIsPopular(JnbKnowledgeBaseDTO));
    }

    /**
     * 小程序查询热门知识列表
     */
    @GetMapping("/popularKnowledgeList")
    public TableDataInfo popularKnowledgeList(JnbKnowledgeBaseVO jnbKnowledgeBaseVO) {
        startPage();
        List<JnbKnowledgeBaseVO> list = jnbKnowledgeBaseService.popularKnowledgeList(jnbKnowledgeBaseVO);
        return getDataTable(list);
    }

    /**
     * 查询已付费的知识库
     */
    @GetMapping("/knowledgePayList")
    public TableDataInfo knowledgePayList(JnbKnowledgeBaseVO jnbKnowledgeBaseVO) {
        startPage();
        List<JnbKnowledgeBaseVO> list = jnbKnowledgeBaseService.knowledgePayList(jnbKnowledgeBaseVO);
        return getDataTable(list);
    }

    /**
     * 判断是否已经购买知识库
     */
    @GetMapping("/knowledgePay")
    public AjaxResult knowledgePay(JnbKnowledgeBaseVO jnbKnowledgeBaseVO) {
        return jnbKnowledgeBaseService.knowledgePay(jnbKnowledgeBaseVO);
    }
}
