package com.ruoyi.web.controller.my;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.sooka.jnb.my.domain.Announcement;
import com.sooka.jnb.my.domain.AnnouncementRead;
import com.sooka.jnb.my.service.IAnnouncementService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 公告Controller
 *
 * @author LG
 * @date 2024-03-02
 */
@RestController
@RequestMapping("/my/announcement")
public class AnnouncementController extends BaseController {
    @Autowired
    private IAnnouncementService announcementService;

    /**
     * 查询公告列表
     */
    @GetMapping("/list")
    public TableDataInfo list(Announcement announcement) {
        startPage();
        List<Announcement> list = announcementService.selectAnnouncementList(announcement);
        return getDataTable(list);
    }


    /**
     * 获取公告详细信息
     */
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return success(announcementService.selectAnnouncementById(id));
    }

    /**
     * 新增公告
     */
    @PostMapping
    public AjaxResult add(@RequestBody Announcement announcement) {
        return toAjax(announcementService.insertAnnouncement(announcement));
    }

    /**
     * 修改公告
     */
    @PutMapping
    public AjaxResult edit(@RequestBody Announcement announcement) {
        return toAjax(announcementService.updateAnnouncement(announcement));
    }

    /**
     * 删除公告
     */
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(announcementService.deleteAnnouncementByIds(ids));
    }

    /**
     * 已读消息
     */
    @PostMapping("/readAnnouncement")
    public AjaxResult readAnnouncement(@RequestBody AnnouncementRead announcement) {
        return toAjax(announcementService.readAnnouncement(announcement));
    }

    /**
     * 查询最新消息（滚动）
     */
    @GetMapping("/getNewAnnouncement")
    public AjaxResult getNewAnnouncement(Announcement announcement) {
        return AjaxResult.success(announcementService.getNewAnnouncement(announcement));
    }
}
