package com.ruoyi.web.controller.my;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.sooka.jnb.my.domain.JnbImg;
import com.sooka.jnb.my.service.IJnbImgService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 图片管理Controller
 * 
 * @author LG
 * @date 2024-03-05
 */
@RestController
@RequestMapping("/my/img")
public class JnbImgController extends BaseController
{
    @Autowired
    private IJnbImgService jnbImgService;

    /**
     * 查询图片管理列表
     */
    @PreAuthorize("@ss.hasPermi('my:img:list')")
    @GetMapping("/list")
    public TableDataInfo list(JnbImg jnbImg)
    {
        startPage();
        List<JnbImg> list = jnbImgService.selectJnbImgList(jnbImg);
        return getDataTable(list);
    }

    /**
     * 导出图片管理列表
     */
    @PreAuthorize("@ss.hasPermi('my:img:export')")
    @Log(title = "图片管理", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, JnbImg jnbImg)
    {
        List<JnbImg> list = jnbImgService.selectJnbImgList(jnbImg);
        ExcelUtil<JnbImg> util = new ExcelUtil<JnbImg>(JnbImg.class);
        util.exportExcel(response, list, "图片管理数据");
    }

    /**
     * 获取图片管理详细信息
     */
    @PreAuthorize("@ss.hasPermi('my:img:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(jnbImgService.selectJnbImgById(id));
    }

    /**
     * 新增图片管理
     */
    @PreAuthorize("@ss.hasPermi('my:img:add')")
    @Log(title = "图片管理", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody JnbImg jnbImg)
    {
        return toAjax(jnbImgService.insertJnbImg(jnbImg));
    }

    /**
     * 修改图片管理
     */
    @PreAuthorize("@ss.hasPermi('my:img:edit')")
    @Log(title = "图片管理", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody JnbImg jnbImg)
    {
        return toAjax(jnbImgService.updateJnbImg(jnbImg));
    }

    /**
     * 删除图片管理
     */
    @PreAuthorize("@ss.hasPermi('my:img:remove')")
    @Log(title = "图片管理", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(jnbImgService.deleteJnbImgByIds(ids));
    }

    /**
     * 查看是否存在封面图片
     */
    @GetMapping("/isCover")
    public AjaxResult isCover(){
        return AjaxResult.success(jnbImgService.isCover());
    }

    /**
     * 获取当前封面图片
     */
    @GetMapping("/getCover")
    public AjaxResult getCover(){
        return AjaxResult.success("操作成功",jnbImgService.getCover());
    }

    /**
     * 获取当前轮播图
     */
    @GetMapping("/getCarousel")
    public AjaxResult getCarousel() {
        return AjaxResult.success(jnbImgService.getCarousel());
    }
}
