package com.ruoyi.web.controller.my;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.sooka.jnb.my.domain.JnbNameAuthentication;
import com.sooka.jnb.my.service.IJnbNameAuthenticationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 实名认证Controller
 *
 * @author 韩福成
 * @date 2024-03-02
 */
@RestController
@RequestMapping("/nameAuthentication")
public class JnbNameAuthenticationController extends BaseController {
    @Autowired
    private IJnbNameAuthenticationService jnbNameAuthenticationService;

    /**
     * 查询实名认证列表
     */
    @PreAuthorize("@ss.hasPermi('nameAuthentication:list')")
    @GetMapping("/list")
    public TableDataInfo list(JnbNameAuthentication jnbNameAuthentication) {
        startPage();
        List<JnbNameAuthentication> list = jnbNameAuthenticationService.selectJnbNameAuthenticationList(jnbNameAuthentication);
        return getDataTable(list);
    }

    /**
     * 导出实名认证列表
     */
    @PreAuthorize("@ss.hasPermi('nameAuthentication:export')")
    @Log(title = "实名认证", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, JnbNameAuthentication jnbNameAuthentication) {
        List<JnbNameAuthentication> list = jnbNameAuthenticationService.selectJnbNameAuthenticationList(jnbNameAuthentication);
        ExcelUtil<JnbNameAuthentication> util = new ExcelUtil<JnbNameAuthentication>(JnbNameAuthentication.class);
        util.exportExcel(response, list, "实名认证数据");
    }

    /**
     * 获取实名认证详细信息
     */
    @PreAuthorize("@ss.hasPermi('nameAuthentication:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return AjaxResult.success(jnbNameAuthenticationService.selectJnbNameAuthenticationById(id));
    }

    /**
     * 新增实名认证
     */
    @PreAuthorize("@ss.hasPermi('nameAuthentication:add')")
    @Log(title = "实名认证", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody JnbNameAuthentication jnbNameAuthentication) {
        return toAjax(jnbNameAuthenticationService.insertJnbNameAuthentication(jnbNameAuthentication));
    }

    /**
     * 修改实名认证
     */
    @PreAuthorize("@ss.hasPermi('nameAuthentication:edit')")
    @Log(title = "实名认证", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody JnbNameAuthentication jnbNameAuthentication) {
        return toAjax(jnbNameAuthenticationService.updateJnbNameAuthentication(jnbNameAuthentication));
    }

    /**
     * 删除实名认证
     */
    @PreAuthorize("@ss.hasPermi('nameAuthentication:remove')")
    @Log(title = "实名认证", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(jnbNameAuthenticationService.deleteJnbNameAuthenticationByIds(ids));
    }

    /*
    * 审核实名认证
    *
    * @author 韩福成
    * @date 2024/3/5 11:09
    */
    @PreAuthorize("@ss.hasPermi('nameAuthentication:edit')")
    @Log(title = "审核实名认证", businessType = BusinessType.UPDATE)
    @PutMapping("/through")
    public AjaxResult through(@RequestBody JnbNameAuthentication jnbNameAuthentication) {
        return toAjax(jnbNameAuthenticationService.through(jnbNameAuthentication));
    }

    /*
    * 小程序-提交实名认证
    *
    * @author 韩福成
    * @date 2024/3/4 14:21
    */
    @Log(title = "实名认证", businessType = BusinessType.INSERT)
    @PostMapping(value = "/appletAdd")
    public AjaxResult appletAdd(@RequestBody JnbNameAuthentication jnbNameAuthentication) {
        return toAjax(jnbNameAuthenticationService.insertJnbNameAuthentication(jnbNameAuthentication));
    }

    /*
    * 小程序-按登录人获取官方认证信息
    *
    * @author 韩福成
    * @date 2024/3/6 14:42
    */
    @GetMapping(value = "getNameInfo/{userId}")
    public R getNameInfo(@PathVariable("userId") String userId) {
        return R.ok(jnbNameAuthenticationService.getNameInfo(userId));
    }
}
