package com.ruoyi.web.controller.my;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.ruoyi.common.core.domain.R;
import com.sooka.jnb.my.domain.JnbOfficialAuthentication;
import com.sooka.jnb.my.service.IJnbOfficialAuthenticationService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 官方认证Controller
 *
 * @author 韩福成
 * @date 2024-03-02
 */
@RestController
@RequestMapping("/officialAuthentication")
public class JnbOfficialAuthenticationController extends BaseController {
    @Autowired
    private IJnbOfficialAuthenticationService jnbOfficialAuthenticationService;

    /**
     * 查询官方认证列表
     */
    @PreAuthorize("@ss.hasPermi('officialAuthentication:list')")
    @GetMapping("/list")
    public TableDataInfo list(JnbOfficialAuthentication jnbOfficialAuthentication) {
        startPage();
        List<JnbOfficialAuthentication> list = jnbOfficialAuthenticationService.selectJnbOfficialAuthenticationList(jnbOfficialAuthentication);
        return getDataTable(list);
    }

    /**
     * 导出官方认证列表
     */
    @PreAuthorize("@ss.hasPermi('officialAuthentication:export')")
    @Log(title = "官方认证", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, JnbOfficialAuthentication jnbOfficialAuthentication) {
        List<JnbOfficialAuthentication> list = jnbOfficialAuthenticationService.selectJnbOfficialAuthenticationList(jnbOfficialAuthentication);
        ExcelUtil<JnbOfficialAuthentication> util = new ExcelUtil<JnbOfficialAuthentication>(JnbOfficialAuthentication.class);
        util.exportExcel(response, list, "官方认证数据");
    }

    /**
     * 获取官方认证详细信息
     */
    @PreAuthorize("@ss.hasPermi('officialAuthentication:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") String id) {
        return success(jnbOfficialAuthenticationService.selectJnbOfficialAuthenticationById(id));
    }

    /**
     * 新增官方认证
     */
    @PreAuthorize("@ss.hasPermi('officialAuthentication:add')")
    @Log(title = "官方认证", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody JnbOfficialAuthentication jnbOfficialAuthentication) {
        return toAjax(jnbOfficialAuthenticationService.insertJnbOfficialAuthentication(jnbOfficialAuthentication));
    }

    /**
     * 修改官方认证
     */
    @PreAuthorize("@ss.hasPermi('officialAuthentication:edit')")
    @Log(title = "官方认证", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody JnbOfficialAuthentication jnbOfficialAuthentication) {
        return toAjax(jnbOfficialAuthenticationService.updateJnbOfficialAuthentication(jnbOfficialAuthentication));
    }

    /**
     * 删除官方认证
     */
    @PreAuthorize("@ss.hasPermi('officialAuthentication:remove')")
    @Log(title = "官方认证", businessType = BusinessType.DELETE)
    @DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable String[] ids) {
        return toAjax(jnbOfficialAuthenticationService.deleteJnbOfficialAuthenticationByIds(ids));
    }

    /*
    * 审核官方认证
    *
    * @author 韩福成
    * @date 2024/3/5 13:55
    */
    @PreAuthorize("@ss.hasPermi('officialAuthentication:edit')")
    @Log(title = "审核官方认证", businessType = BusinessType.UPDATE)
    @PutMapping("/through")
    public AjaxResult through(@RequestBody JnbOfficialAuthentication jnbOfficialAuthentication) {
        return toAjax(jnbOfficialAuthenticationService.through(jnbOfficialAuthentication));
    }

    /*
    * 小程序-官方认证提交
    *
    * @author 韩福成
    * @date 2024/3/4 16:24
    */
    @Log(title = "官方认证", businessType = BusinessType.INSERT)
    @PostMapping("/appletAdd")
    public AjaxResult appletAdd(@RequestBody JnbOfficialAuthentication jnbOfficialAuthentication) {
        return toAjax(jnbOfficialAuthenticationService.insertJnbOfficialAuthentication(jnbOfficialAuthentication));
    }

    /*
     * 小程序-按登录人获取实名认证信息
     *
     * @author 韩福成
     * @date 2024/3/6 14:42
     */
    @GetMapping(value = "getOfficialInfo/{userId}")
    public R getOfficialInfo(@PathVariable("userId") String userId) {
        return R.ok(jnbOfficialAuthenticationService.getOfficialInfo(userId));
    }
}
