package com.ruoyi.web.controller.my;

import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.page.TableDataInfo;
import com.sooka.jnb.my.domain.ScoreOperate;
import com.sooka.jnb.my.service.IScoreService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

@RestController
@RequestMapping("/score")
public class ScoreController extends BaseController {
    @Autowired
    private IScoreService service;

    /**
     * 初始化积分
     *
     * @param scoreOperate 积分操作实体
     * @return AjaxResult
     */
    @PostMapping("/initScore")
    public AjaxResult initScore(@RequestBody ScoreOperate scoreOperate) {
        if (service.soleVerify(scoreOperate.getUserId())) {
            return AjaxResult.error("用户已存在, 不能初始化积分!");
        }
        if (service.initScore(scoreOperate) > 0) {
            return AjaxResult.success();
        } else {
            return AjaxResult.error("初始化积分失败!");
        }
    }

    /**
     * 获取积分
     *
     * @param userId 用户ID
     * @return AjaxResult
     */
    @GetMapping("/getScore")
    public R<ScoreOperate> getScore(@RequestParam String userId) {
        return R.ok(service.getScore(userId));
    }

    /**
     * 获取用户积分列表
     */
    @GetMapping("/getList")
    public TableDataInfo getList(ScoreOperate scoreOperate) {
        startPage();
        return getDataTable(service.getList(scoreOperate));
    }

    /**
     * 获取积分流水
     */
    @GetMapping("/getScoreList")
    public TableDataInfo getScoreList(ScoreOperate scoreOperate) {
        startPage();
        return getDataTable(service.getScoreList(scoreOperate));
    }

    /**
     * 增加积分
     */
    @PostMapping("/addScore")
    public AjaxResult addScore(@RequestBody ScoreOperate scoreOperate) {
        if (service.addScore(scoreOperate) > 0) {
            return AjaxResult.success();
        } else {
            return AjaxResult.error("增加积分失败!");
        }
    }


    /**
     * 减少积分
     */
    @PostMapping("/reduceScore")
    public AjaxResult reduceScore(@RequestBody ScoreOperate scoreOperate) {
        if (service.verifyScore(scoreOperate)) {
            if (service.reduceScore(scoreOperate) > 0) {
                return AjaxResult.success();
            } else {
                return AjaxResult.error("减少积分失败!");
            }
        } else {
            return AjaxResult.error("用户积分不足!");
        }
    }

    /**
     * 验证积分是否充足
     */
    @GetMapping("/verifyScore")
    public AjaxResult verifyScore(ScoreOperate scoreOperate) {
        return AjaxResult.success(service.verifyScore(scoreOperate));
    }
}
