package com.ruoyi.web.controller.quotations;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.sooka.jnb.quotations.domain.JnbQuotationsConfig;
import com.sooka.jnb.quotations.service.IJnbQuotationsConfigService;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;

import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 行情产品配置Controller
 *
 * @author ruoyi
 * @date 2024-03-01
 */
@RestController
@RequestMapping("/quotationsConfig")
public class JnbQuotationsConfigController extends BaseController {
    @Autowired
    private IJnbQuotationsConfigService jnbQuotationsConfigService;

    /**
     * 查询行情产品配置列表
     */
//    @PreAuthorize("@ss.hasPermi('jnb:config:list')")
    @GetMapping("/list")
    public TableDataInfo list(JnbQuotationsConfig jnbQuotationsConfig) {
        startPage();
        List<JnbQuotationsConfig> list = jnbQuotationsConfigService.selectJnbQuotationsConfigList(jnbQuotationsConfig);
        return getDataTable(list);
    }

    /**
     * 获取行情产品配置详细信息
     */
//    @PreAuthorize("@ss.hasPermi('jnb:config:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id) {
        return success(jnbQuotationsConfigService.selectJnbQuotationsConfigById(id));
    }

    /**
     * 新增行情产品配置
     */
//    @PreAuthorize("@ss.hasPermi('jnb:config:add')")
    @Log(title = "行情产品配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody JnbQuotationsConfig jnbQuotationsConfig) {
        int i = jnbQuotationsConfigService.insertJnbQuotationsConfig(jnbQuotationsConfig);
        if (i > 0){
            return toAjax(i);
        }else {
            return AjaxResult.error("同级已存在相同名称产品");
        }
    }

    /**
     * 修改行情产品配置
     */
//    @PreAuthorize("@ss.hasPermi('jnb:config:edit')")
    @Log(title = "行情产品配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody JnbQuotationsConfig jnbQuotationsConfig) {
        return AjaxResult.success(jnbQuotationsConfigService.updateJnbQuotationsConfig(jnbQuotationsConfig));

    }

    /**
     * 删除行情产品配置
     */
//    @PreAuthorize("@ss.hasPermi('jnb:config:remove')")
    @Log(title = "行情产品配置", businessType = BusinessType.DELETE)
    @DeleteMapping("/{id}")
    public AjaxResult remove(@PathVariable("id") Long id) {
        int i = jnbQuotationsConfigService.deleteJnbQuotationsConfigByIds(id);
        if (i > 0){
            return toAjax(i);
        }else {
            return AjaxResult.error("存在子级产品");
        }
    }

    /**
     * 查询树结构
     */
//    @PreAuthorize("@ss.hasPermi('jnb:config:list')")
    @Log(title = "行情产品配置")
    @GetMapping("all")
    public AjaxResult all(JnbQuotationsConfig jnbQuotationsConfig) {
        return AjaxResult.success(jnbQuotationsConfigService.quotationsTree(jnbQuotationsConfig));
    }
}
