package com.ruoyi.web.controller.quotations;

import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.sooka.jnb.quotations.domain.JnbQuotations;
import com.sooka.jnb.quotations.service.IJnbQuotationsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 行情Controller
 * 
 * @author ruoyi
 * @date 2024-03-01
 */
@RestController
@RequestMapping("/quotations")
public class JnbQuotationsController extends BaseController
{
    @Autowired
    private IJnbQuotationsService jnbQuotationsService;

    /**
     * 查询行情列表
     */
//    @PreAuthorize("@ss.hasPermi('jnb:quotations:list')")
    @GetMapping("/list")
    public TableDataInfo list(JnbQuotations jnbQuotations)
    {
        startPage();
        List<JnbQuotations> list = jnbQuotationsService.selectJnbQuotationsList(jnbQuotations);
        return getDataTable(list);
    }

    /**
     * 获取行情详细信息
     */
//    @PreAuthorize("@ss.hasPermi('jnb:quotations:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(jnbQuotationsService.selectJnbQuotationsById(id));
    }

    /**
     * 新增行情
     */
//    @PreAuthorize("@ss.hasPermi('jnb:quotations:add')")
    @Log(title = "新增行情", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody JnbQuotations jnbQuotations)
    {
        int i = jnbQuotationsService.insertJnbQuotations(jnbQuotations);
        if (i > 0) {
            return toAjax(i);
        } else {
            return AjaxResult.error("产品名称已存在");
        }
    }

    /**
     * 修改行情
     */
//    @PreAuthorize("@ss.hasPermi('jnb:quotations:edit')")
    @Log(title = "修改行情", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody JnbQuotations jnbQuotations)
    {
            return AjaxResult.success( jnbQuotationsService.updateJnbQuotations(jnbQuotations));

    }

    /**
     * 删除行情
     */
//    @PreAuthorize("@ss.hasPermi('jnb:quotations:remove')")
    @Log(title = "删除行情", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable("ids") Long[] ids)
    {
        return toAjax(jnbQuotationsService.deleteJnbQuotationsByIds(ids));
    }

    /**
     * 审核
     */
//    @PreAuthorize("@ss.hasPermi('jnb:quotations:remove')")
    @Log(title = "审核", businessType = BusinessType.DELETE)
    @PostMapping("/status")
    public AjaxResult remove(@RequestBody JnbQuotations jnbQuotations)
    {
        return toAjax(jnbQuotationsService.updateByStatusAndId(jnbQuotations));
    }
}
