package com.sooka.jnb.asking.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.sooka.jnb.asking.domain.JnbAnswer;
import com.sooka.jnb.asking.mapper.JnbAnswerMapper;
import com.sooka.jnb.asking.service.IJnbAnswerService;
import com.sooka.jnb.my.domain.ScoreOperate;
import com.sooka.jnb.my.service.IScoreService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 问答列-答案Service业务层处理
 *
 * @author 韩福成
 * @date 2024-03-13
 */
@Service
public class JnbAnswerServiceImpl implements IJnbAnswerService {
    @Autowired
    private JnbAnswerMapper jnbAnswerMapper;

    @Autowired
    private IScoreService iScoreService;

    /**
     * 查询问答列-答案
     *
     * @param id 问答列-答案主键
     * @return 问答列-答案
     */
    @Override
    public JnbAnswer selectJnbAnswerById(String id) {
        return jnbAnswerMapper.selectJnbAnswerById(id);
    }

    /**
     * 查询问答列-答案列表
     *
     * @param jnbAnswer 问答列-答案
     * @return 问答列-答案
     */
    @Override
    public List<JnbAnswer> selectJnbAnswerList(JnbAnswer jnbAnswer) {
        return jnbAnswerMapper.selectJnbAnswerList(jnbAnswer);
    }

    /**
     * 新增问答列-答案
     *
     * @param jnbAnswer 问答列-答案
     * @return 结果
     */
    @Override
    public int insertJnbAnswer(JnbAnswer jnbAnswer) {
        jnbAnswer.setCreateTime(DateUtils.getNowDate());
        return jnbAnswerMapper.insertJnbAnswer(jnbAnswer);
    }

    /**
     * 修改问答列-答案
     *
     * @param jnbAnswer 问答列-答案
     * @return 结果
     */
    @Override
    public int updateJnbAnswer(JnbAnswer jnbAnswer) {
        jnbAnswer.setUpdateTime(DateUtils.getNowDate());
        return jnbAnswerMapper.updateJnbAnswer(jnbAnswer);
    }

    /**
     * 批量删除问答列-答案
     *
     * @param ids 需要删除的问答列-答案主键
     * @return 结果
     */
    @Override
    public int deleteJnbAnswerByIds(String[] ids) {
        return jnbAnswerMapper.deleteJnbAnswerByIds(ids);
    }

    /**
     * 删除问答列-答案信息
     *
     * @param id 问答列-答案主键
     * @return 结果
     */
    @Override
    public int deleteJnbAnswerById(String id) {
        return jnbAnswerMapper.deleteJnbAnswerById(id);
    }

    /*
    * 小程序-添加答案
    *
    * @author 韩福成
    * @date 2024/3/13 14:50
    */
    @Override
    public int addAnswer(JnbAnswer jnbAnswer) {
        jnbAnswer.setId(IdUtils.simpleUUID());
        jnbAnswer.setCreateTime(DateUtils.getNowDate());
        jnbAnswer.setDataStatus("1");
        return jnbAnswerMapper.insertJnbAnswer(jnbAnswer);
    }

    /*
    * 小程序-答案采纳
    *
    * @author 韩福成
    * @date 2024/3/14 11:22
    */
    @Override
    public int adoptAnswer(JnbAnswer jnbAnswer) {
        jnbAnswer.setAdopt("1");
        ScoreOperate scoreOperate = new ScoreOperate();
        scoreOperate.setUserId(jnbAnswer.getCreateBy());
        scoreOperate.setScoreNum(Integer.valueOf(jnbAnswer.getScore()));
        scoreOperate.setRelevance("2");
        scoreOperate.setRelevanceDataId(jnbAnswer.getId());
        iScoreService.addScore(scoreOperate);
        return jnbAnswerMapper.updateJnbAnswer(jnbAnswer);
    }
}
