package com.sooka.jnb.asking.service.impl;

import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.sooka.jnb.asking.domain.JnbQuestionCollect;
import com.sooka.jnb.asking.mapper.JnbQuestionCollectMapper;
import com.sooka.jnb.asking.service.IJnbQuestionCollectService;
import org.apache.commons.lang3.ObjectUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 问题收藏Service业务层处理
 *
 * @author 韩福成
 * @date 2024-03-13
 */
@Service
public class JnbQuestionCollectServiceImpl implements IJnbQuestionCollectService {
    @Autowired
    private JnbQuestionCollectMapper jnbQuestionCollectMapper;

    /**
     * 查询问题收藏
     *
     * @param id 问题收藏主键
     * @return 问题收藏
     */
    @Override
    public JnbQuestionCollect selectJnbQuestionCollectById(String id) {
        return jnbQuestionCollectMapper.selectJnbQuestionCollectById(id);
    }

    /**
     * 查询问题收藏列表
     *
     * @param jnbQuestionCollect 问题收藏
     * @return 问题收藏
     */
    @Override
    public List<JnbQuestionCollect> selectJnbQuestionCollectList(JnbQuestionCollect jnbQuestionCollect) {
        return jnbQuestionCollectMapper.selectJnbQuestionCollectList(jnbQuestionCollect);
    }

    /**
     * 新增问题收藏
     *
     * @param jnbQuestionCollect 问题收藏
     * @return 结果
     */
    @Override
    public int insertJnbQuestionCollect(JnbQuestionCollect jnbQuestionCollect) {
        jnbQuestionCollect.setId(IdUtils.simpleUUID());
        return jnbQuestionCollectMapper.insertJnbQuestionCollect(jnbQuestionCollect);
    }

    /**
     * 修改问题收藏
     *
     * @param jnbQuestionCollect 问题收藏
     * @return 结果
     */
    @Override
    public int updateJnbQuestionCollect(JnbQuestionCollect jnbQuestionCollect) {
        return jnbQuestionCollectMapper.updateJnbQuestionCollect(jnbQuestionCollect);
    }

    /**
     * 批量删除问题收藏
     *
     * @param ids 需要删除的问题收藏主键
     * @return 结果
     */
    @Override
    public int deleteJnbQuestionCollectByIds(String[] ids) {
        return jnbQuestionCollectMapper.deleteJnbQuestionCollectByIds(ids);
    }

    /**
     * 删除问题收藏信息
     *
     * @param id 问题收藏主键
     * @return 结果
     */
    @Override
    public int deleteJnbQuestionCollectById(String id) {
        return jnbQuestionCollectMapper.deleteJnbQuestionCollectById(id);
    }

    /*
    * 小程序-添加（取消）收藏
    *
    * @author 韩福成
    * @date 2024/3/14 8:47
    */
    @Override
    public int addCollect(JnbQuestionCollect jnbQuestionCollect) {
        List<JnbQuestionCollect> jnbQuestionCollects = jnbQuestionCollectMapper.selectJnbQuestionCollectList(jnbQuestionCollect);
        if (jnbQuestionCollects.isEmpty()){
            //添加收藏
            jnbQuestionCollect.setId(IdUtils.simpleUUID());
            return jnbQuestionCollectMapper.insertJnbQuestionCollect(jnbQuestionCollect);
        }else {
            //取消收藏
            return jnbQuestionCollectMapper.deleteJnbQuestionCollect(jnbQuestionCollect.getQuestionId());
        }
    }

    /*
    * 小程序-判断是否收藏
    *
    * @author 韩福成
    * @date 2024/3/14 9:09
    */
    @Override
    public List<JnbQuestionCollect> selectCollect(JnbQuestionCollect jnbQuestionCollect) {
        return jnbQuestionCollectMapper.selectJnbQuestionCollectList(jnbQuestionCollect);
    }
}
