package com.sooka.jnb.asking.service.impl;

import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.sooka.jnb.asking.domain.JnbAnswer;
import com.sooka.jnb.asking.domain.JnbQuestion;
import com.sooka.jnb.asking.domain.JnbQuestionImg;
import com.sooka.jnb.asking.mapper.JnbQuestionMapper;
import com.sooka.jnb.asking.service.IJnbAnswerService;
import com.sooka.jnb.asking.service.IJnbQuestionService;
import com.sooka.jnb.my.domain.Announcement;
import com.sooka.jnb.my.domain.ScoreOperate;
import com.sooka.jnb.my.service.IAnnouncementService;
import com.sooka.jnb.my.service.IScoreService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.List;

import static com.ruoyi.common.constant.CacheConstants.SYS_CONFIG_KEY;

/**
 * 问答列-问题Service业务层处理
 *
 * @author 韩福成
 * @date 2024-03-11
 */
@Service
public class JnbQuestionServiceImpl implements IJnbQuestionService {
    @Autowired
    private JnbQuestionMapper jnbQuestionMapper;

    @Autowired
    private IAnnouncementService announcementService;

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private IJnbAnswerService jnbAnswerService;

    @Autowired
    private IScoreService iScoreService;

    /**
     * 查询问答列-问题
     *
     * @param id 问答列-问题主键
     * @return 问答列-问题
     */
    @Override
    public JnbQuestion selectJnbQuestionById(String id) {
        JnbQuestion question = jnbQuestionMapper.selectJnbQuestionById(id);
        if (StringUtils.isNotEmpty(question.getPath())){
            String[] split = question.getPath().split(",");
            question.setPaths(split);
        }
        JnbAnswer jnbAnswer = new JnbAnswer();
        jnbAnswer.setQuestionId(id);
        List<JnbAnswer> answerList = jnbAnswerService.selectJnbAnswerList(jnbAnswer);
        question.setAnswerList(answerList);
        return question;
    }

    /**
     * 查询问答列-问题列表
     *
     * @param jnbQuestion 问答列-问题
     * @return 问答列-问题
     */
    @Override
    public List<JnbQuestion> selectJnbQuestionList(JnbQuestion jnbQuestion) {
        return jnbQuestionMapper.selectJnbQuestionList(jnbQuestion);
    }

    /**
     * 新增问答列-问题
     *
     * @param jnbQuestion 问答列-问题
     * @return 结果
     */
    @Override
    public int insertJnbQuestion(JnbQuestion jnbQuestion) {
        jnbQuestion.setId(IdUtils.simpleUUID());
        jnbQuestion.setCreateBy(SecurityUtils.getUserId().toString());
        jnbQuestion.setCreateTime(DateUtils.getNowDate());
        jnbQuestion.setDataStatus("1");
        jnbQuestion.setStatus("3");
        jnbQuestion.setWhetherShow("N");
        if (jnbQuestion.getPath()!=null){
            String[] paths = jnbQuestion.getPath().split(",");
            for (String path : paths) {
                JnbQuestionImg img = new JnbQuestionImg();
                img.setId(IdUtils.simpleUUID());
                img.setQuestionId(jnbQuestion.getId());
                img.setPath(path);
                jnbQuestionMapper.insertJnbQuestionImg(img);
            }
        }
        return jnbQuestionMapper.insertJnbQuestion(jnbQuestion);
    }

    /**
     * 修改问答列-问题
     *
     * @param jnbQuestion 问答列-问题
     * @return 结果
     */
    @Override
    public int updateJnbQuestion(JnbQuestion jnbQuestion) {
        jnbQuestion.setUpdateBy(SecurityUtils.getUserId().toString());
        jnbQuestion.setUpdateTime(DateUtils.getNowDate());
        jnbQuestionMapper.deleteQuestionImg(jnbQuestion.getId());
        if (jnbQuestion.getPath()!=null){
            String[] paths = jnbQuestion.getPath().split(",");
            for (String path : paths) {
                JnbQuestionImg img = new JnbQuestionImg();
                img.setId(IdUtils.simpleUUID());
                img.setQuestionId(jnbQuestion.getId());
                img.setPath(path);
                jnbQuestionMapper.insertJnbQuestionImg(img);
            }
        }
        return jnbQuestionMapper.updateJnbQuestion(jnbQuestion);
    }

    /*
    * 修改是否展示
    *
    * @author 韩福成
    * @date 2024/3/14 10:23
    */
    @Override
    public int updateWhetherShow(JnbQuestion jnbQuestion) {
        return jnbQuestionMapper.updateJnbQuestion(jnbQuestion);
    }

    /**
     * 批量删除问答列-问题
     *
     * @param ids 需要删除的问答列-问题主键
     * @return 结果
     */
    @Override
    public int deleteJnbQuestionByIds(String[] ids) {
        return jnbQuestionMapper.deleteJnbQuestionByIds(ids);
    }

    /**
     * 删除问答列-问题信息
     *
     * @param id 问答列-问题主键
     * @return 结果
     */
    @Override
    public int deleteJnbQuestionById(String id) {
        return jnbQuestionMapper.deleteJnbQuestionById(id);
    }

    /*
    * 审核
    *
    * @author 韩福成
    * @date 2024/3/11 11:25
    */
    @Override
    public int through(JnbQuestion jnbQuestion) {
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String data = simpleDateFormat.format(jnbQuestion.getCreateTime());
        Announcement announcement = new Announcement();
        announcement.setUserId(IdUtils.simpleUUID());
        announcement.setCreateBy(SecurityUtils.getUserId().toString());
        String type = DictUtils.getDictLabel("examine_state",jnbQuestion.getStatus());
        announcement.setAnnouncementTitle(type+":[问答]");
        announcement.setAnnouncementBody("您在"+data+"发起的[问答]信息已["+type+"]");
        announcement.setAnnoType("jnb_question");
        announcement.setBindId(jnbQuestion.getId());
        announcementService.insertAnnouncement(announcement);
        if (jnbQuestion.getStatus().equals("1")){
            //减少积分
            ScoreOperate scoreOperate = new ScoreOperate();
            scoreOperate.setUserId(jnbQuestion.getCreateBy());
            scoreOperate.setScoreNum(Integer.valueOf(jnbQuestion.getScore()));
            scoreOperate.setRelevance("2");
            scoreOperate.setRelevanceDataId(jnbQuestion.getId());
            iScoreService.reduceScore(scoreOperate);
        }
        return jnbQuestionMapper.updateJnbQuestion(jnbQuestion);
    }

    /*
    * 小程序-获取热门问答列表
    *
    * @author 韩福成
    * @date 2024/3/11 14:28
    */
    @Override
    public List<JnbQuestion> getHotQuestionList(JnbQuestion jnbQuestion) {
        Long hotNum = Long.valueOf(redisCache.getCacheObject(SYS_CONFIG_KEY + "init_socre").toString());
        jnbQuestion.setBrowse(hotNum);
        return jnbQuestionMapper.getHotQuestionList(jnbQuestion);
    }

    /*
    * 小程序-按类型查询问题
    *
    * @author 韩福成
    * @date 2024/3/12 13:04
    */
    @Override
    public List<JnbQuestion> getQuestionByType(JnbQuestion jnbQuestion) {
        List<JnbQuestion> list = jnbQuestionMapper.getQuestionByType(jnbQuestion);
        for (JnbQuestion ques : list){
            if (StringUtils.isNotEmpty(ques.getPath())){
                String[] split = ques.getPath().split(",");
                ques.setPaths(split);
            }
        }
        return list;
    }

    /*
    * 小程序-按类型查询精彩回答问题列表
    *
    * @author 韩福成
    * @date 2024/3/12 15:53
    */
    @Override
    public List<JnbQuestion> getExcitingAnswersList(JnbQuestion jnbQuestion) {
        List<JnbQuestion> list = jnbQuestionMapper.getExcitingAnswersList(jnbQuestion);
        for (JnbQuestion ques : list){
            if (StringUtils.isNotEmpty(ques.getPath())){
                String[] split = ques.getPath().split(",");
                ques.setPaths(split);
            }
        }
        return list;
    }

    /*
    * 小程序-按类型查询最多悬赏问题列表
    *
    * @author 韩福成
    * @date 2024/3/12 15:53
    */
    @Override
    public List<JnbQuestion> getMaxScoreList(JnbQuestion jnbQuestion) {
        List<JnbQuestion> list = jnbQuestionMapper.getMaxScoreList(jnbQuestion);
        for (JnbQuestion ques : list){
            if (StringUtils.isNotEmpty(ques.getPath())){
                String[] split = ques.getPath().split(",");
                ques.setPaths(split);
            }
        }
        return list;
    }

    /*
    * 小程序-获取问题详情
    *
    * @author 韩福成
    * @date 2024/3/13 14:10
    */
    @Override
    public JnbQuestion getDetailById(String id) {
        JnbQuestion question = jnbQuestionMapper.selectJnbQuestionById(id);
        JnbQuestion jnbQuestion = new JnbQuestion();
        jnbQuestion.setId(id);
        jnbQuestion.setBrowse(question.getBrowse()+1);
        jnbQuestionMapper.updateJnbQuestion(jnbQuestion);
        if (StringUtils.isNotEmpty(question.getPath())){
            String[] split = question.getPath().split(",");
            question.setPaths(split);
        }
        JnbAnswer jnbAnswer = new JnbAnswer();
        jnbAnswer.setQuestionId(id);
        List<JnbAnswer> answerList = jnbAnswerService.selectJnbAnswerList(jnbAnswer);
        question.setAnswerList(answerList);
        return question;
    }
}
