package com.sooka.jnb.asking.service.impl;

import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.sooka.jnb.asking.domain.JnbQuestionType;
import com.sooka.jnb.asking.mapper.JnbQuestionTypeMapper;
import com.sooka.jnb.asking.service.IJnbQuestionTypeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 类型配置Service业务层处理
 *
 * @author 韩福成
 * @date 2024-03-01
 */
@Service
public class JnbQuestionTypeServiceImpl implements IJnbQuestionTypeService {
    @Autowired
    private JnbQuestionTypeMapper jnbQuestionTypeMapper;

    /**
     * 查询类型配置
     *
     * @param id 类型配置主键
     * @return 类型配置
     */
    @Override
    public JnbQuestionType selectJnbQuestionTypeById(String id) {
        return jnbQuestionTypeMapper.selectJnbQuestionTypeById(id);
    }

    /**
     * 查询类型配置列表
     *
     * @param jnbQuestionType 类型配置
     * @return 类型配置
     */
    @Override
    public List<JnbQuestionType> selectJnbQuestionTypeList(JnbQuestionType jnbQuestionType) {
        return jnbQuestionTypeMapper.selectJnbQuestionTypeList(jnbQuestionType);
    }

    /**
     * 新增类型配置
     *
     * @param jnbQuestionType 类型配置
     * @return 结果
     */
    @Override
    public int insertJnbQuestionType(JnbQuestionType jnbQuestionType) {
        jnbQuestionType.setId(IdUtils.simpleUUID());
        jnbQuestionType.setCreateBy(SecurityUtils.getUserId().toString());
        jnbQuestionType.setCreateTime(DateUtils.getNowDate());
        jnbQuestionType.setDataStatus("1");
        jnbQuestionTypeMapper.insertJnbQuestionType(jnbQuestionType);
        jnbQuestionType.setTypeId(jnbQuestionType.getId());
        jnbQuestionType.setId(IdUtils.simpleUUID());
        return jnbQuestionTypeMapper.insertJnbQuestionTypePath(jnbQuestionType);
    }

    /**
     * 修改类型配置
     *
     * @param jnbQuestionType 类型配置
     * @return 结果
     */
    @Override
    public int updateJnbQuestionType(JnbQuestionType jnbQuestionType) {
        jnbQuestionType.setUpdateBy(SecurityUtils.getUserId().toString());
        jnbQuestionType.setUpdateTime(DateUtils.getNowDate());
        jnbQuestionTypeMapper.updateJnbQuestionTypeImg(jnbQuestionType);
        return jnbQuestionTypeMapper.updateJnbQuestionType(jnbQuestionType);
    }

    /*
    * 修改是否展示
    *
    * @author 韩福成
    * @date 2024/3/14 10:17
    */
    @Override
    public int updataType(JnbQuestionType jnbQuestionType) {
        return jnbQuestionTypeMapper.updateJnbQuestionType(jnbQuestionType);
    }

    /**
     * 批量删除类型配置
     *
     * @param ids 需要删除的类型配置主键
     * @return 结果
     */
    @Override
    public int deleteJnbQuestionTypeByIds(String[] ids) {
        return jnbQuestionTypeMapper.deleteJnbQuestionTypeByIds(ids);
    }

    /*
    * 按类型查询
    *
    * @author 韩福成
    * @date 2024/3/1 14:07
    */
    @Override
    public List<JnbQuestionType> selectJnbQuestionByType(JnbQuestionType jnbQuestionType) {
        return jnbQuestionTypeMapper.selectJnbQuestionByType(jnbQuestionType);
    }
}
