package com.sooka.jnb.cooperative.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.sooka.jnb.cooperative.domain.Cooperative;
import com.sooka.jnb.cooperative.mapper.CooperativeMapper;
import org.springframework.stereotype.Service;
import com.sooka.jnb.cooperative.service.ICooperativeService;

import javax.annotation.Resource;

/**
 * 供销合作社Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-03-01
 */
@Service
public class CooperativeServiceImpl implements ICooperativeService 
{
    @Resource
    private CooperativeMapper cooperativeMapper;

    /**
     * 查询供销合作社
     * 
     * @param id 供销合作社主键
     * @return 供销合作社
     */
    @Override
    public Cooperative selectCooperativeById(Long id)
    {
        return cooperativeMapper.selectCooperativeById(id);
    }

    /**
     * 查询供销合作社列表
     * 
     * @param jnbSupplyAndMarketingCooperative 供销合作社
     * @return 供销合作社
     */
    @Override
    public List<Cooperative> selectCooperativeList(Cooperative jnbSupplyAndMarketingCooperative)
    {
        return cooperativeMapper.selectCooperativeList(jnbSupplyAndMarketingCooperative);
    }

    /**
     * 新增供销合作社
     * 
     * @param jnbSupplyAndMarketingCooperative 供销合作社
     * @return 结果
     */
    @Override
    public int insertCooperative(Cooperative jnbSupplyAndMarketingCooperative)
    {
        String operatorName = SecurityUtils.getUsername();
        jnbSupplyAndMarketingCooperative.setCreateBy(operatorName);
        jnbSupplyAndMarketingCooperative.setCreateTime(DateUtils.getNowDate());
        return cooperativeMapper.insertCooperative(jnbSupplyAndMarketingCooperative);
    }

    /**
     * 修改供销合作社
     * 
     * @param jnbSupplyAndMarketingCooperative 供销合作社
     * @return 结果
     */
    @Override
    public int updateCooperative(Cooperative jnbSupplyAndMarketingCooperative)
    {
        String operatorName = SecurityUtils.getUsername();
        jnbSupplyAndMarketingCooperative.setUpdateBy(operatorName);
        jnbSupplyAndMarketingCooperative.setUpdateTime(DateUtils.getNowDate());
        return cooperativeMapper.updateCooperative(jnbSupplyAndMarketingCooperative);
    }

    /**
     * 批量删除供销合作社
     * 
     * @param ids 需要删除的供销合作社主键
     * @return 结果
     */
    @Override
    public int deleteCooperativeByIds(Long[] ids)
    {
        return cooperativeMapper.deleteCooperativeByIds(ids);
    }

    /**
     * 删除供销合作社信息
     * 
     * @param id 供销合作社主键
     * @return 结果
     */
    @Override
    public int deleteCooperativeById(Long id)
    {
        return cooperativeMapper.deleteCooperativeById(id);
    }
}
