package com.sooka.jnb.handleAffairs.service.impl;


import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.sooka.jnb.handleAffairs.domain.GridType;
import com.sooka.jnb.handleAffairs.mapper.GridTypeMapper;
import com.sooka.jnb.handleAffairs.service.IGridTypeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 网格类型配置Service业务层处理
 * 
 * @author lidongyu
 * @date 2024-03-01
 */
@Service
public class GridTypeServiceImpl implements IGridTypeService 
{
    @Autowired
    private GridTypeMapper gridTypeMapper;

    /**
     * 查询网格类型配置
     * 
     * @param id 网格类型配置主键
     * @return 网格类型配置
     */
    @Override
    public GridType selectGridTypeById(Long id)
    {
        return gridTypeMapper.selectGridTypeById(id);
    }

    /**
     * 查询网格类型配置列表
     * 
     * @param gridType 网格类型配置
     * @return 网格类型配置
     */
    @Override
    public List<GridType> selectGridTypeList(GridType gridType)
    {
        return gridTypeMapper.selectGridTypeList(gridType);
    }

    /**
     * 新增网格类型配置
     * 
     * @param gridType 网格类型配置
     * @return 结果
     */
    @Override
    public int insertGridType(GridType gridType)
    {
        gridType.setCreateTime(DateUtils.getNowDate());
        gridType.setCreateBy(SecurityUtils.getUserId().toString());
        gridType.setDelFlag("0");
        return gridTypeMapper.insertGridType(gridType);
    }

    /**
     * 修改网格类型配置
     * 
     * @param gridType 网格类型配置
     * @return 结果
     */
    @Override
    public int updateGridType(GridType gridType)
    {
        gridType.setUpdateTime(DateUtils.getNowDate());
        gridType.setUpdateBy(SecurityUtils.getUserId().toString());
        return gridTypeMapper.updateGridType(gridType);
    }

    /**
     * 批量删除网格类型配置
     * 
     * @param ids 需要删除的网格类型配置主键
     * @return 结果
     */
    @Override
    public int deleteGridTypeByIds(Long[] ids)
    {
        return gridTypeMapper.deleteGridTypeByIds(ids);
    }

    /**
     * 删除网格类型配置信息
     * 
     * @param id 网格类型配置主键
     * @return 结果
     */
    @Override
    public int deleteGridTypeById(Long id)
    {
        return gridTypeMapper.deleteGridTypeById(id);
    }
}
