package com.sooka.jnb.handleAffairs.service.impl;

import java.util.Arrays;
import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.sooka.jnb.handleAffairs.domain.TopicType;
import com.sooka.jnb.handleAffairs.mapper.TopicTypeMapper;
import com.sooka.jnb.handleAffairs.service.ITopicTypeService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

/**
 * 主题类型配置Service业务层处理
 * 
 * @author lidongyu
 * @date 2024-03-01
 */
@Service
public class TopicTypeServiceImpl implements ITopicTypeService
{
    @Autowired
    private TopicTypeMapper topicTypeMapper;

    /**
     * 查询主题类型配置
     * 
     * @param id 主题类型配置主键
     * @return 主题类型配置
     */
    @Override
    public TopicType selectTopicTypeById(Long id)
    {   TopicType topicType = topicTypeMapper.selectTopicTypeById(id);
        topicType.setObjectOfHandlingArray(Arrays.asList(topicType.getObjectOfHandling().split(",")));
        return topicType;
    }

    /**
     * 查询主题类型配置列表
     * 
     * @param topicType 主题类型配置
     * @return 主题类型配置
     */
    @Override
    public List<TopicType> selectTopicTypeList(TopicType topicType)
    {
        List<TopicType> list = topicTypeMapper.selectTopicTypeList(topicType);
        list.forEach(e->{
            e.setObjectOfHandlingArray(Arrays.asList(e.getObjectOfHandling().split(",")));
        });
        return list;
    }

    /**
     * 新增主题类型配置
     * 
     * @param topicType 主题类型配置
     * @return 结果
     */
    @Override
    public int insertTopicType(TopicType topicType)
    {
        topicType.setCreateTime(DateUtils.getNowDate());
        topicType.setCreateBy(SecurityUtils.getUserId().toString());
        topicType.setDelFlag("0");
        topicType.setObjectOfHandling(String.join(",",topicType.getObjectOfHandlingArray()));
        return topicTypeMapper.insertTopicType(topicType);
    }

    /**
     * 修改主题类型配置
     * 
     * @param topicType 主题类型配置
     * @return 结果
     */
    @Override
    public int updateTopicType(TopicType topicType)
    {
        topicType.setUpdateTime(DateUtils.getNowDate());
        topicType.setUpdateBy(SecurityUtils.getUserId().toString());
        topicType.setObjectOfHandling(String.join(",",topicType.getObjectOfHandlingArray()));
        return topicTypeMapper.updateTopicType(topicType);
    }

    /**
     * 批量删除主题类型配置
     * 
     * @param ids 需要删除的主题类型配置主键
     * @return 结果
     */
    @Override
    public int deleteTopicTypeByIds(Long[] ids)
    {
        return topicTypeMapper.deleteTopicTypeByIds(ids);
    }

    /**
     * 删除主题类型配置信息
     * 
     * @param id 主题类型配置主键
     * @return 结果
     */
    @Override
    public int deleteTopicTypeById(Long id)
    {
        return topicTypeMapper.deleteTopicTypeById(id);
    }
}
