package com.sooka.jnb.highServer.service.impl;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.sooka.jnb.highServer.domain.JnbHighServer;
import com.sooka.jnb.highServer.domain.JnbHighServerImg;
import com.sooka.jnb.highServer.mapper.JnbHighServerImgMapper;
import com.sooka.jnb.highServer.mapper.JnbHighServerMapper;
import com.sooka.jnb.highServer.service.IJnbHighServerService;
import com.sooka.jnb.highServer.vo.JnbHighServerVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;


/**
 * 高频服务Service业务层处理
 *
 * @author ruoyi
 * @date 2024-03-01
 */
@Service
public class JnbHighServerServiceImpl implements IJnbHighServerService {

    @Autowired
    private JnbHighServerMapper jnbHighServerMapper;
    @Autowired
    private JnbHighServerImgMapper jnbHighServerImgMapper;

    /**
     * 查询高频服务
     *
     * @param id 高频服务主键
     * @return 高频服务
     */
    @Override
    public JnbHighServerVO selectJnbHighServerById(Long id, Integer type) {
        return jnbHighServerMapper.selectJnbHighServerById(id, type);
    }

    /**
     * 查询高频服务列表
     *
     * @param jnbHighServerVO 高频服务
     * @return 高频服务
     */
    @Override
    public List<JnbHighServerVO> selectJnbHighServerList(JnbHighServerVO jnbHighServerVO) {
        return jnbHighServerMapper.selectJnbHighServerList(jnbHighServerVO);
    }

    /**
     * 新增高频服务
     *
     * @param jnbHighServerVO 高频服务
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertJnbHighServer(JnbHighServerVO jnbHighServerVO) {
        jnbHighServerVO.setCreateBy(SecurityUtils.getUsername());
        jnbHighServerVO.setCreateTime(DateUtils.getNowDate());
        jnbHighServerMapper.insertJnbHighServer(jnbHighServerVO);
        if (StringUtils.isNotEmpty(jnbHighServerVO.getImgUrlList())) {
            List<String> imgUrlArray = Arrays.asList(jnbHighServerVO.getImgUrlList().split(","));
            List<JnbHighServerImg> saveList = new ArrayList<>();
            for (int i = 0; i < imgUrlArray.size(); i++) {
                JnbHighServerImg jnbHighServerImg = new JnbHighServerImg();
                jnbHighServerImg.setServerId(jnbHighServerVO.getId());
                jnbHighServerImg.setType(jnbHighServerVO.getType());
                jnbHighServerImg.setImgUrl(imgUrlArray.get(i));
                saveList.add(jnbHighServerImg);
            }
            return jnbHighServerImgMapper.saveJnbHighServerImg(saveList);
        }
        return 1;
    }

    /**
     * 修改高频服务
     *
     * @param jnbHighServerVO 高频服务
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateJnbHighServer(JnbHighServerVO jnbHighServerVO) {
        jnbHighServerVO.setUpdateBy(SecurityUtils.getUsername());
        jnbHighServerVO.setUpdateTime(DateUtils.getNowDate());
        jnbHighServerMapper.updateJnbHighServer(jnbHighServerVO);
        if (StringUtils.isNotEmpty(jnbHighServerVO.getImgUrlList())) {
            jnbHighServerImgMapper.deleteJnbHighServerByServerId(jnbHighServerVO.getId(), jnbHighServerVO.getType());
            List<String> imgUrlArray = Arrays.asList(jnbHighServerVO.getImgUrlList().split(","));
            List<JnbHighServerImg> saveList = new ArrayList<>();
            for (int i = 0; i < imgUrlArray.size(); i++) {
                JnbHighServerImg jnbHighServerImg = new JnbHighServerImg();
                jnbHighServerImg.setServerId(jnbHighServerVO.getId());
                jnbHighServerImg.setType(jnbHighServerVO.getType());
                jnbHighServerImg.setImgUrl(imgUrlArray.get(i));
                saveList.add(jnbHighServerImg);
            }
            return jnbHighServerImgMapper.saveJnbHighServerImg(saveList);
        }
        return 1;
    }

    /**
     * 批量删除高频服务
     *
     * @param ids 需要删除的高频服务主键
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int deleteJnbHighServerByIds(Long[] ids, Integer type) {
        jnbHighServerImgMapper.deleteJnbHighServerByServerIds(ids, type);
        return jnbHighServerMapper.deleteJnbHighServerByIds(ids, type);
    }

    /**
     * 删除高频服务信息
     *
     * @param id 高频服务主键
     * @return 结果
     */
    @Override
    public int deleteJnbHighServerById(Long id, Integer type) {
        return jnbHighServerMapper.deleteJnbHighServerById(id, type);
    }

    @Override
    public List<JnbHighServerVO> getLiveBroadcast(JnbHighServer jnbHighServer) {
        List<JnbHighServerVO> list = jnbHighServerMapper.getLiveBroadcast(jnbHighServer);
        for (JnbHighServerVO var : list) {
            if (StringUtils.isNotEmpty(var.getImgUrlList())) {
                var.setPictureList(Arrays.asList(var.getImgUrlList().split(",")));
            }
        }
        return list;
    }

    @Override
    public JnbHighServerVO liveBroadcastDetails(Long id) {
        JnbHighServerVO jnbHighServerVO = jnbHighServerMapper.liveBroadcastDetails(id);
        if (StringUtils.isNotEmpty(jnbHighServerVO.getImgUrlList())) {
            jnbHighServerVO.setPictureList(Arrays.asList(jnbHighServerVO.getImgUrlList().split(",")));
        }
        jnbHighServerMapper.updateLikeNumber(id,5);
        jnbHighServerMapper.updateWatchNumber(id,5);
        return jnbHighServerVO;
    }

    @Override
    public List<JnbHighServerVO> getLifeServices(JnbHighServer jnbHighServer) {
        List<JnbHighServerVO> list = jnbHighServerMapper.getLifeServices(jnbHighServer);
        for (JnbHighServerVO var : list) {
            if (StringUtils.isNotEmpty(var.getImgUrlList())) {
                var.setPictureList(Arrays.asList(var.getImgUrlList().split(",")));
            }
        }
        return list;
    }

    @Override
    public JnbHighServerVO lifeServicesDetails(Long id) {
        JnbHighServerVO jnbHighServerVO = jnbHighServerMapper.lifeServicesDetails(id);
        if (StringUtils.isNotEmpty(jnbHighServerVO.getImgUrlList())) {
            jnbHighServerVO.setPictureList(Arrays.asList(jnbHighServerVO.getImgUrlList().split(",")));
        }
        jnbHighServerMapper.updateLikeNumber(id,6);
        jnbHighServerMapper.updateWatchNumber(id,6);
        return jnbHighServerVO;
    }

    @Override
    public List<JnbHighServerVO> getTravelGuide(JnbHighServer jnbHighServer) {
        List<JnbHighServerVO> list = jnbHighServerMapper.getTravelGuide(jnbHighServer);
        for (JnbHighServerVO var : list) {
            if (StringUtils.isNotEmpty(var.getImgUrlList())) {
                var.setPictureList(Arrays.asList(var.getImgUrlList().split(",")));
            }
        }
        return list;
    }
    @Override
    public JnbHighServerVO travelGuideDetails(Long id) {
        JnbHighServerVO jnbHighServerVO = jnbHighServerMapper.travelGuideDetails(id);
        if (StringUtils.isNotEmpty(jnbHighServerVO.getImgUrlList())) {
            jnbHighServerVO.setPictureList(Arrays.asList(jnbHighServerVO.getImgUrlList().split(",")));
        }
        jnbHighServerMapper.updateLikeNumber(id,1);
        jnbHighServerMapper.updateWatchNumber(id,1);
        return jnbHighServerVO;
    }

    @Override
    public List<JnbHighServerVO> getPsychology(JnbHighServer jnbHighServer) {
        List<JnbHighServerVO> list = jnbHighServerMapper.getPsychology(jnbHighServer);
        for (JnbHighServerVO var : list) {
            if (StringUtils.isNotEmpty(var.getImgUrlList())) {
                var.setPictureList(Arrays.asList(var.getImgUrlList().split(",")));
            }
        }
        return list;
    }
    @Override
    public JnbHighServerVO psychologyDetails(Long id) {
        JnbHighServerVO jnbHighServerVO = jnbHighServerMapper.psychologyDetails(id);
        if (StringUtils.isNotEmpty(jnbHighServerVO.getImgUrlList())) {
            jnbHighServerVO.setPictureList(Arrays.asList(jnbHighServerVO.getImgUrlList().split(",")));
        }
        jnbHighServerMapper.updateLikeNumber(id,2);
        jnbHighServerMapper.updateWatchNumber(id,2);
        return jnbHighServerVO;
    }

    @Override
    public List<JnbHighServerVO> getLoveAtVillage(JnbHighServer jnbHighServer) {
        List<JnbHighServerVO> list = jnbHighServerMapper.getLoveAtVillage(jnbHighServer);
        for (JnbHighServerVO var : list) {
            if (StringUtils.isNotEmpty(var.getImgUrlList())) {
                var.setPictureList(Arrays.asList(var.getImgUrlList().split(",")));
            }
        }
        return list;
    }
    @Override
    public JnbHighServerVO loveAtVillageDetails(Long id) {
        JnbHighServerVO jnbHighServerVO = jnbHighServerMapper.loveAtVillageDetails(id);
        if (StringUtils.isNotEmpty(jnbHighServerVO.getImgUrlList())) {
            jnbHighServerVO.setPictureList(Arrays.asList(jnbHighServerVO.getImgUrlList().split(",")));
        }
        jnbHighServerMapper.updateLikeNumber(id,7);
        jnbHighServerMapper.updateWatchNumber(id,7);
        return jnbHighServerVO;
    }

    @Override
    public List<JnbHighServerVO> getLegalService(JnbHighServer jnbHighServer) {
        List<JnbHighServerVO> list = jnbHighServerMapper.getLegalService(jnbHighServer);
        for (JnbHighServerVO var : list) {
            if (StringUtils.isNotEmpty(var.getImgUrlList())) {
                var.setPictureList(Arrays.asList(var.getImgUrlList().split(",")));
            }
        }
        return list;
    }
    @Override
    public JnbHighServerVO legalServiceDetails(Long id) {
        JnbHighServerVO jnbHighServerVO = jnbHighServerMapper.legalServiceDetails(id);
        if (StringUtils.isNotEmpty(jnbHighServerVO.getImgUrlList())) {
            jnbHighServerVO.setPictureList(Arrays.asList(jnbHighServerVO.getImgUrlList().split(",")));
        }
        jnbHighServerMapper.updateLikeNumber(id,8);
        jnbHighServerMapper.updateWatchNumber(id,8);
        return jnbHighServerVO;
    }

    @Override
    public List<JnbHighServerVO> getFinancialInfrastructure(JnbHighServer jnbHighServer) {
        List<JnbHighServerVO> list = jnbHighServerMapper.getFinancialInfrastructure(jnbHighServer);
        for (JnbHighServerVO var : list) {
            if (StringUtils.isNotEmpty(var.getImgUrlList())) {
                var.setPictureList(Arrays.asList(var.getImgUrlList().split(",")));
            }
        }
        return list;
    }
    @Override
    public JnbHighServerVO financialInfrastructureDetails(Long id) {
        JnbHighServerVO jnbHighServerVO = jnbHighServerMapper.financialInfrastructureDetails(id);
        if (StringUtils.isNotEmpty(jnbHighServerVO.getImgUrlList())) {
            jnbHighServerVO.setPictureList(Arrays.asList(jnbHighServerVO.getImgUrlList().split(",")));
        }
        jnbHighServerMapper.updateLikeNumber(id,9);
        jnbHighServerMapper.updateWatchNumber(id,9);
        return jnbHighServerVO;
    }

    @Override
    public List<JnbHighServerVO> getInquiry(JnbHighServer jnbHighServer) {
        List<JnbHighServerVO> list = jnbHighServerMapper.getInquiry(jnbHighServer);
        for (JnbHighServerVO var : list) {
            if (StringUtils.isNotEmpty(var.getImgUrlList())) {
                var.setPictureList(Arrays.asList(var.getImgUrlList().split(",")));
            }
        }
        return list;
    }
    @Override
    public JnbHighServerVO inquiryDetails(Long id) {
        JnbHighServerVO jnbHighServerVO = jnbHighServerMapper.inquiryDetails(id);
        if (StringUtils.isNotEmpty(jnbHighServerVO.getImgUrlList())) {
            jnbHighServerVO.setPictureList(Arrays.asList(jnbHighServerVO.getImgUrlList().split(",")));
        }
        jnbHighServerMapper.updateLikeNumber(id,3);
        jnbHighServerMapper.updateWatchNumber(id,3);
        return jnbHighServerVO;
    }

    @Override
    public List<JnbHighServerVO> getHelp(JnbHighServer jnbHighServer) {
        List<JnbHighServerVO> list = jnbHighServerMapper.getHelp(jnbHighServer);
        for (JnbHighServerVO var : list) {
            if (StringUtils.isNotEmpty(var.getImgUrlList())) {
                var.setPictureList(Arrays.asList(var.getImgUrlList().split(",")));
            }
        }
        return list;
    }
    @Override
    public JnbHighServerVO helpDetails(Long id) {
        JnbHighServerVO jnbHighServerVO = jnbHighServerMapper.helpDetails(id);
        if (StringUtils.isNotEmpty(jnbHighServerVO.getImgUrlList())) {
            jnbHighServerVO.setPictureList(Arrays.asList(jnbHighServerVO.getImgUrlList().split(",")));
        }
        jnbHighServerMapper.updateLikeNumber(id,4);
        jnbHighServerMapper.updateWatchNumber(id,4);
        return jnbHighServerVO;
    }
}
