package com.sooka.jnb.information.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.sooka.jnb.highServer.domain.JnbHighServerImg;
import com.sooka.jnb.highServer.mapper.JnbHighServerImgMapper;
import com.sooka.jnb.information.domain.Information;
import com.sooka.jnb.information.domain.InformationUni;
import com.sooka.jnb.information.mapper.InformationMapper;
import com.sooka.jnb.information.service.InformationService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.ObjectUtils;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

/**
 * 高频服务Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-03-01
 */
@Service
public class InformationServiceImpl implements InformationService
{
    @Autowired
    private InformationMapper informationMapper;
    @Autowired
    private JnbHighServerImgMapper jnbHighServerImgMapper;

    @Override
    public Information selectInformationById(Long id,Integer type)
    {
        Information information = informationMapper.selectInformationById(id,type);
        information.setImgUrlList(jnbHighServerImgMapper.selectAll(id,information.getType()));
        return information;
    }
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Information selectInformationByIdgetInfoUniApp(Long id,Integer type)
    {
        Information information = informationMapper.selectInformationById(id,type);
        information.setUrls(jnbHighServerImgMapper.selectAllList(id,information.getType()));
        informationMapper.updateInformationWatch(information);
        return information;
    }

    @Override
    public List<Information> selectInformationList(Information information)
    {
        return informationMapper.selectInformationList(information);
    }

    @Override
    public List<InformationUni> selectInformationListWx(Information information)
    {
        List<Information> list = informationMapper.selectInformationListWx(information);
        return list.stream().map(item -> {
            InformationUni uni = new InformationUni();
            BeanUtils.copyProperties(item, uni);
            return uni;
        }).collect(Collectors.toList());
    }
    @Override
    public List<Information> selectInformationListWxs(Information information)
    {
        List<Information> list = informationMapper.selectInformationListWxs(information);
        for (Information information1 : list) {
            if (information1.getImgUrlList()!=null){
                String[] split = information1.getImgUrlList().split(",");
                information1.setUrls(Arrays.asList(split));
            }
            else {
                information1.setUrls(new ArrayList<>(0));
            }
        }
        return list;
    }


    @Override
    public int likeById(Information information) {
       return informationMapper.updateInformationLike(information);
    }

    @Override
    public int watchById(Information information) {
       return informationMapper.updateInformationWatch(information);
    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertInformationServer(Information entity)
    {
        entity.setCreateTime(DateUtils.getNowDate());
        entity.setCreateBy(String.valueOf(SecurityUtils.getUserId()));
        int i = informationMapper.insertInformation(entity);
        if (i>0){
            if (!ObjectUtils.isEmpty(entity.getImgUrlList())){
                List<String> imgUrlList = Arrays.asList(entity.getImgUrlList().split(","));
                List<JnbHighServerImg> imgList = new ArrayList<>();
                imgUrlList.forEach(a->{
                    JnbHighServerImg serverImg = new JnbHighServerImg();
                    serverImg.setCreateBy(String.valueOf(SecurityUtils.getUserId()));
                    serverImg.setCreateTime(DateUtils.getNowDate());
                    serverImg.setServerId(entity.getId());
                    serverImg.setImgUrl(a);
                    serverImg.setType(entity.getType());
                    imgList.add(serverImg);
                });
                jnbHighServerImgMapper.saveJnbHighServerImg(imgList);
            }
        }
        return i;
    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertInformationServerUni(InformationUni entity)
    {
        entity.setCreateTime(DateUtils.getNowDate());
        entity.setCreateBy(String.valueOf(SecurityUtils.getUserId()));
        Information obj = new Information();
        BeanUtils.copyProperties(entity,obj);
        int i = informationMapper.insertInformation(obj);
        if (i>0){
            if (!ObjectUtils.isEmpty(entity.getUrls())){
                List<JnbHighServerImg> imgList = new ArrayList<>();
                entity.getUrls().forEach(a->{
                    JnbHighServerImg serverImg = new JnbHighServerImg();
                    serverImg.setCreateBy(String.valueOf(SecurityUtils.getUserId()));
                    serverImg.setCreateTime(DateUtils.getNowDate());
                    serverImg.setServerId(entity.getId());
                    serverImg.setImgUrl(a);
                    serverImg.setType(entity.getType());
                    imgList.add(serverImg);
                });
                jnbHighServerImgMapper.saveJnbHighServerImg(imgList);
            }
        }
        return i;
    }


    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateInformation(Information entity)
    {
        entity.setUpdateTime(DateUtils.getNowDate());
        entity.setUpdateBy(String.valueOf(SecurityUtils.getUserId()));
        int i = informationMapper.updateInformation(entity);
        if (!ObjectUtils.isEmpty(entity.getImgUrlList())){
            List<String> imgUrlList = Arrays.asList(entity.getImgUrlList().split(","));
                List<JnbHighServerImg> imgList = new ArrayList<>();
                jnbHighServerImgMapper.deleteJnbHighServerByServerId(entity.getId(),entity.getType());
                imgUrlList.forEach(a->{
                    JnbHighServerImg serverImg = new JnbHighServerImg();
                    serverImg.setCreateBy(String.valueOf(SecurityUtils.getUserId()));
                    serverImg.setCreateTime(DateUtils.getNowDate());
                    serverImg.setServerId(entity.getId());
                    serverImg.setImgUrl(a);
                    serverImg.setType(entity.getType());
                    imgList.add(serverImg);
                });
                jnbHighServerImgMapper.saveJnbHighServerImg(imgList);
            }
        return i;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateInformationUni(InformationUni entity)
    {
        entity.setUpdateTime(DateUtils.getNowDate());
        entity.setUpdateBy(String.valueOf(SecurityUtils.getUserId()));
        Information obj = new Information();
        BeanUtils.copyProperties(entity,obj);
        int i = informationMapper.updateInformation(obj);
        if (!ObjectUtils.isEmpty(entity.getUrls())){
            List<JnbHighServerImg> imgList = new ArrayList<>();
            jnbHighServerImgMapper.deleteJnbHighServerByServerId(entity.getId(),entity.getType());
            entity.getUrls().forEach(a->{
                JnbHighServerImg serverImg = new JnbHighServerImg();
                serverImg.setCreateBy(String.valueOf(SecurityUtils.getUserId()));
                serverImg.setCreateTime(DateUtils.getNowDate());
                serverImg.setServerId(entity.getId());
                serverImg.setImgUrl(a);
                serverImg.setType(entity.getType());
                imgList.add(serverImg);
            });
            jnbHighServerImgMapper.saveJnbHighServerImg(imgList);
        }
        return i;
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public int deleteInformationByIds(Long[] ids,Integer type)
    {
        int i = informationMapper.deleteInformationByIds(ids,type);
        if (i>0){
            jnbHighServerImgMapper.deleteJnbHighServerByServerIds(ids,type);
        }
        return i;
    }

}
