package com.sooka.jnb.knowledge.service.impl;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;

import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.sooka.jnb.highServer.domain.JnbHighServerImg;
import com.sooka.jnb.knowledge.domain.JnbKnowledgeBaseImg;
import com.sooka.jnb.knowledge.dto.JnbKnowledgeBaseDTO;
import com.sooka.jnb.knowledge.mapper.JnbKnowledgeBaseImgMapper;
import com.sooka.jnb.knowledge.mapper.JnbKnowledgeBaseMapper;
import com.sooka.jnb.knowledge.service.IJnbKnowledgeBaseService;
import com.sooka.jnb.knowledge.vo.JnbKnowledgeBaseVO;
import com.sooka.jnb.my.domain.ScoreOperate;
import com.sooka.jnb.my.service.IScoreService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

/**
 * 知识库Service业务层处理
 *
 * @author ruoyi
 * @date 2024-03-02
 */
@Service
public class JnbKnowledgeBaseServiceImpl implements IJnbKnowledgeBaseService {
    @Autowired
    private JnbKnowledgeBaseMapper jnbKnowledgeBaseMapper;
    @Autowired
    private JnbKnowledgeBaseImgMapper jnbKnowledgeBaseImgMapper;
    @Autowired
    private IScoreService service;

    /**
     * 查询知识库j
     *
     * @param id 知识库主键
     * @return 知识库
     */
    @Override
    public JnbKnowledgeBaseVO selectJnbKnowledgeBaseById(Long id) {
        jnbKnowledgeBaseMapper.updateWatchNum(id);
        return jnbKnowledgeBaseMapper.selectJnbKnowledgeBaseById(id);
    }

    /**
     * 查询知识库列表
     *
     * @param jnbKnowledgeBaseVO 知识库
     * @return 知识库
     */
    @Override
    public List<JnbKnowledgeBaseVO> selectJnbKnowledgeBaseList(JnbKnowledgeBaseVO jnbKnowledgeBaseVO) {
        return jnbKnowledgeBaseMapper.selectJnbKnowledgeBaseList(jnbKnowledgeBaseVO);
    }

    /**
     * 新增知识库
     *
     * @param jnbKnowledgeBaseVO 知识库
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertJnbKnowledgeBase(JnbKnowledgeBaseVO jnbKnowledgeBaseVO) {
        jnbKnowledgeBaseVO.setPopular(false);
        jnbKnowledgeBaseVO.setCreateId(SecurityUtils.getUserId().toString());
        jnbKnowledgeBaseVO.setCreateTime(DateUtils.getNowDate());
        jnbKnowledgeBaseMapper.insertJnbKnowledgeBase(jnbKnowledgeBaseVO);
        if (StringUtils.isNotEmpty(jnbKnowledgeBaseVO.getImgUrlList())) {
            List<String> imgUrlArray = Arrays.asList(jnbKnowledgeBaseVO.getImgUrlList().split(","));
            List<JnbKnowledgeBaseImg> saveList = new ArrayList<>();
            for (int i = 0; i < imgUrlArray.size(); i++) {
                JnbKnowledgeBaseImg jnbKnowledgeBaseImg = new JnbKnowledgeBaseImg();
                jnbKnowledgeBaseImg.setKnowledgeId(jnbKnowledgeBaseVO.getId());
                jnbKnowledgeBaseImg.setImgUrl(imgUrlArray.get(i));
                saveList.add(jnbKnowledgeBaseImg);
            }
            return jnbKnowledgeBaseImgMapper.saveJnbKnowledgeBaseImg(saveList);
        }
        return 1;
    }

    /**
     * 修改知识库
     *
     * @param jnbKnowledgeBaseVO 知识库
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int updateJnbKnowledgeBase(JnbKnowledgeBaseVO jnbKnowledgeBaseVO) {
        jnbKnowledgeBaseVO.setUpdateBy(SecurityUtils.getUsername());
        jnbKnowledgeBaseVO.setUpdateTime(DateUtils.getNowDate());
        jnbKnowledgeBaseMapper.updateJnbKnowledgeBase(jnbKnowledgeBaseVO);
        if (StringUtils.isNotEmpty(jnbKnowledgeBaseVO.getImgUrlList())) {
            jnbKnowledgeBaseImgMapper.deleteJnbKnowledgeBaseImgByServerId(jnbKnowledgeBaseVO.getId());
            List<String> imgUrlArray = Arrays.asList(jnbKnowledgeBaseVO.getImgUrlList().split(","));
            List<JnbKnowledgeBaseImg> saveList = new ArrayList<>();
            for (int i = 0; i < imgUrlArray.size(); i++) {
                JnbKnowledgeBaseImg jnbKnowledgeBaseImg = new JnbKnowledgeBaseImg();
                jnbKnowledgeBaseImg.setKnowledgeId(jnbKnowledgeBaseVO.getId());
                jnbKnowledgeBaseImg.setImgUrl(imgUrlArray.get(i));
                saveList.add(jnbKnowledgeBaseImg);
            }
            return jnbKnowledgeBaseImgMapper.saveJnbKnowledgeBaseImg(saveList);
        }
        return 1;
    }

    /**
     * 批量删除知识库
     *
     * @param ids 需要删除的知识库主键
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int deleteJnbKnowledgeBaseByIds(Long[] ids) {
        jnbKnowledgeBaseImgMapper.deleteJnbKnowledgeBaseImgByServerIds(ids);
        return jnbKnowledgeBaseMapper.deleteJnbKnowledgeBaseByIds(ids);
    }

    /**
     * 删除知识库信息
     *
     * @param id 知识库主键
     * @return 结果
     */
    @Override
    public int deleteJnbKnowledgeBaseById(Long id) {
        return jnbKnowledgeBaseMapper.deleteJnbKnowledgeBaseById(id);
    }

    @Override
    public int updateIsPopular(JnbKnowledgeBaseDTO jnbKnowledgeBaseDTO) {
        return jnbKnowledgeBaseMapper.updateIsPopular(jnbKnowledgeBaseDTO);
    }

    @Override
    public List<JnbKnowledgeBaseVO> popularKnowledgeList(JnbKnowledgeBaseVO jnbKnowledgeBaseVO) {
        return jnbKnowledgeBaseMapper.popularKnowledgeList(jnbKnowledgeBaseVO);
    }

    @Override
    public List<JnbKnowledgeBaseVO> knowledgePayList(JnbKnowledgeBaseVO jnbKnowledgeBaseVO) {
        return jnbKnowledgeBaseMapper.knowledgePayList(jnbKnowledgeBaseVO);
    }

    @Override
    public AjaxResult knowledgePay(JnbKnowledgeBaseVO jnbKnowledgeBaseVO) {
        if (jnbKnowledgeBaseVO.getIntegral() != 0) {
            ScoreOperate scoreOperate = new ScoreOperate();
            scoreOperate.setUserId(jnbKnowledgeBaseVO.getUserId());
            scoreOperate.setScoreNum(Integer.valueOf(Math.toIntExact(jnbKnowledgeBaseVO.getIntegral())));
            scoreOperate.setRelevance("1");
            scoreOperate.setRelevanceDataId(jnbKnowledgeBaseVO.getId().toString());
            int count = service.knowledgeWhetherToPay(jnbKnowledgeBaseVO.getCreateId(), jnbKnowledgeBaseVO.getId().toString());
            if (count > 0) {
                return AjaxResult.success();
            } else {
                if (!service.verifyScore(scoreOperate)) {
                    return AjaxResult.error("积分不足");
                } else {
                    if (service.reduceScore(scoreOperate) > 0) {
                        scoreOperate.setUserId(jnbKnowledgeBaseVO.getCreateId());
                        service.addScore(scoreOperate);
                    } else {
                        return AjaxResult.error("减少积分失败!");
                    }
                }
            }
            return AjaxResult.success();
        }
        return AjaxResult.success();
    }
}
