package com.sooka.jnb.my.domain;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.ruoyi.common.core.domain.BaseEntity;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;
import org.apache.ibatis.type.Alias;

import java.util.Date;

@EqualsAndHashCode(callSuper = true)
@Data
@Alias("announcement")
public class Announcement extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /** 数据id */
    private String id;

    /** 公告标题 */
    private String announcementTitle;

    /** 公告内容 */
    private String announcementBody;

    /** 公告有效期开始时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date validityStartTime;

    /** 公告有效期结束时间 */
    @JsonFormat(pattern = "yyyy-MM-dd")
    private Date validityEndTime;

    /** 公告图片 */
    private String announcementImg;

    /** 所属人员id（系统公告此项为null） */
    private String userId;

    /** 消息状态（1：已读；0：未读） */
    private String readType;

    /**
     * 公告类型
     */
    private String annoType;

    /**
     * 绑定数据id
     */
    private String bindId;

    public Announcement() {
    }

    public Announcement(String announcementTitle, String announcementBody, Date validityStartTime, Date validatyEndTime) {
        this.announcementTitle = announcementTitle;
        this.announcementBody = announcementBody;
        this.validityStartTime = validityStartTime;
        this.validityEndTime = validatyEndTime;
    }

    public Announcement(String announcementTitle, String announcementBody, String userId) {
        this.announcementTitle = announcementTitle;
        this.announcementBody = announcementBody;
        this.userId = userId;
    }

    @Override
    public String toString() {
        return new ToStringBuilder(this, ToStringStyle.MULTI_LINE_STYLE)
                .append("id", getId())
                .append("announcementTitle", getAnnouncementTitle())
                .append("announcementBody", getAnnouncementBody())
                .append("validityStartTime", getValidityStartTime())
                .append("validityEndTime", getValidityEndTime())
                .append("announcementImg", getAnnouncementImg())
                .append("userId", getUserId())
                .append("createBy", getCreateBy())
                .append("createTime", getCreateTime())
                .append("updateBy", getUpdateBy())
                .append("updateTime", getUpdateTime())
                .toString();
    }
}
