package com.sooka.jnb.my.service;

import com.sooka.jnb.my.domain.ScoreOperate;
import org.apache.ibatis.annotations.Param;

import java.util.List;

public interface IScoreService {

    /**
     * 初始化积分
     *
     * @param score 积分实体类
     *              - userId 用户ID
     *              - scoreNum 初始化积分
     *              - createTime 创建时间
     */
    int initScore(ScoreOperate score);

    /**
     * 获取积分
     *
     * @param userId 用户id
     */
    ScoreOperate getScore(String userId);

    /**
     * 查询积分信息列表
     */
    List<ScoreOperate> getList(ScoreOperate score);

    /**
     * 获取积分流水
     */
    List<ScoreOperate> getScoreList(ScoreOperate score);

    /**
     * 增加积分
     *
     * @param scoreOperate 积分操作实体
     *                     - userId 用户id
     *                     - scoreNum 增加的分数
     *                     - createTime 创建时间
     *                     - relevance 操作来源（字典值：key=score_type）
     *                     - relevanceDataId 关联id
     * @return int (>0:扣除成功)
     */
    int addScore(ScoreOperate scoreOperate);

    /**
     * 减少积分
     *
     * @param scoreOperate 积分操作实体
     *                     - userId 用户id
     *                     - scoreNum 减少的分数
     *                     - createTime 创建时间
     *                     - relevance 操作来源（字典值：key=score_type）
     *                     - relevanceDataId 关联id
     */
    int reduceScore(ScoreOperate scoreOperate);

    /**
     * 校验剩余积分
     *
     * @param score 积分操作实体
     *              - userId 用户Id
     *              - scoreNum  要扣除的分数
     * @return boolean 积分充足返回true,积分不足返回false
     */
    boolean verifyScore(ScoreOperate score);

    /**
     * 唯一校验
     *
     * @param userId 用户id
     * @return boolean 用户存在返回true,不存在则返回false
     */
    boolean soleVerify(String userId);

    int knowledgeWhetherToPay(String userId, String relevanceDataId);
}
