package com.sooka.jnb.my.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.StringUtils;
import com.sooka.jnb.my.domain.Announcement;
import com.sooka.jnb.my.domain.AnnouncementRead;
import com.sooka.jnb.my.mapper.AnnouncementMapper;
import com.sooka.jnb.my.service.IAnnouncementService;
import com.sooka.jnb.utils.UUID;
import org.springframework.stereotype.Service;


import javax.annotation.Resource;
import java.util.List;

/**
 * 公告Service业务层处理
 *
 * @author LG
 * @date 2024-03-02
 */
@Service
public class AnnouncementServiceImpl implements IAnnouncementService {
    @Resource
    private AnnouncementMapper announcementMapper;

    /**
     * 查询公告
     *
     * @param id 公告主键
     * @return 公告
     */
    @Override
    public Announcement selectAnnouncementById(String id) {
        return announcementMapper.selectAnnouncementById(id);
    }

    /**
     * 查询公告列表
     *
     * @param announcement 公告
     * @return 公告
     */
    @Override
    public List<Announcement> selectAnnouncementList(Announcement announcement) {
        return announcementMapper.selectAnnouncementList(announcement);
    }

    /**
     * 新增公告
     *
     * @param announcement 公告
     * @return 结果
     */
    @Override
    public int insertAnnouncement(Announcement announcement) {
        announcement.setId(UUID.getUUID());
        //如果请求参数中没有创建人, 则从缓存中获取.
        if (announcement.getCreateBy() == null || "".equals(announcement.getCreateBy())) {
            announcement.setCreateBy(SecurityUtils.getUserId().toString());
        }

        if(announcement.getValidityStartTime() == null){
            announcement.setValidityStartTime(DateUtils.getNowDate());
        }
        announcement.setCreateTime(DateUtils.getNowDate());
        return announcementMapper.insertAnnouncement(announcement);
    }

    /**
     * 修改公告
     *
     * @param announcement 公告
     * @return 结果
     */
    @Override
    public int updateAnnouncement(Announcement announcement) {
        announcement.setUpdateBy(SecurityUtils.getUserId().toString());
        announcement.setUpdateTime(DateUtils.getNowDate());
        return announcementMapper.updateAnnouncement(announcement);
    }

    /**
     * 批量删除公告
     *
     * @param ids 需要删除的公告主键
     * @return 结果
     */
    @Override
    public int deleteAnnouncementByIds(String[] ids) {
        return announcementMapper.deleteAnnouncementByIds(ids);
    }

    /**
     * 删除公告信息
     *
     * @param id 公告主键
     * @return 结果
     */
    @Override
    public int deleteAnnouncementById(String id) {
        return announcementMapper.deleteAnnouncementById(id);
    }

    /**
     * 新增已读消息记录
     *
     * @param announcement
     * @return
     */

    @Override
    public int readAnnouncement(AnnouncementRead announcement) {
        announcement.setId(UUID.getUUID());
        announcement.setCreateTime(DateUtils.getNowDate());
        return announcementMapper.readAnnouncement(announcement);
    }

    @Override
    public List<Announcement> getNewAnnouncement(Announcement announcement) {
        announcement.setReadType("0");
        List<Announcement> dataList = announcementMapper.getNewAnnouncement(announcement);
        if(StringUtils.isEmpty(dataList)){
            announcement.setReadType("1");
            return announcementMapper.getNewAnnouncement(announcement);
        }
        return dataList;
    }
}
