package com.sooka.jnb.my.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.sooka.jnb.my.domain.Announcement;
import com.sooka.jnb.my.domain.JnbAuthenticationImg;
import com.sooka.jnb.my.domain.JnbNameAuthentication;
import com.sooka.jnb.my.mapper.JnbNameAuthenticationMapper;
import com.sooka.jnb.my.service.IAnnouncementService;
import com.sooka.jnb.my.service.IJnbNameAuthenticationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.List;

/**
 * 实名认证Service业务层处理
 *
 * @author 韩福成
 * @date 2024-03-02
 */
@Service
public class JnbNameAuthenticationServiceImpl implements IJnbNameAuthenticationService {
    @Autowired
    private JnbNameAuthenticationMapper jnbNameAuthenticationMapper;

    @Autowired
    private IAnnouncementService announcementService;

    /**
     * 查询实名认证
     *
     * @param id 实名认证主键
     * @return 实名认证
     */
    @Override
    public JnbNameAuthentication selectJnbNameAuthenticationById(String id) {
        return jnbNameAuthenticationMapper.selectJnbNameAuthenticationById(id);
    }

    /**
     * 查询实名认证列表
     *
     * @param jnbNameAuthentication 实名认证
     * @return 实名认证
     */
    @Override
    public List<JnbNameAuthentication> selectJnbNameAuthenticationList(JnbNameAuthentication jnbNameAuthentication) {
        return jnbNameAuthenticationMapper.selectJnbNameAuthenticationList(jnbNameAuthentication);
    }

    /**
     * 新增实名认证
     *
     * @param jnbNameAuthentication 实名认证
     * @return 结果
     */
    @Override
    public int insertJnbNameAuthentication(JnbNameAuthentication jnbNameAuthentication) {
        jnbNameAuthentication.setId(IdUtils.simpleUUID());
        jnbNameAuthentication.setCreateBy(SecurityUtils.getUserId().toString());
        jnbNameAuthentication.setCreateTime(DateUtils.getNowDate());
        jnbNameAuthentication.setDelFlag("1");
        jnbNameAuthentication.setStatus("3");
        if (jnbNameAuthentication.getPath()!=null){
            String[] paths = jnbNameAuthentication.getPath().split(",");
            for (String path : paths) {
                JnbAuthenticationImg img = new JnbAuthenticationImg();
                img.setId(IdUtils.simpleUUID());
                img.setAuthenticationId(jnbNameAuthentication.getId());
                img.setPath(path);
                jnbNameAuthenticationMapper.insertJnbAuthenticationImg(img);
            }
        }

        return jnbNameAuthenticationMapper.insertJnbNameAuthentication(jnbNameAuthentication);
    }

    /**
     * 修改实名认证
     *
     * @param jnbNameAuthentication 实名认证
     * @return 结果
     */
    @Override
    public int updateJnbNameAuthentication(JnbNameAuthentication jnbNameAuthentication) {
        jnbNameAuthentication.setUpdateTime(DateUtils.getNowDate());
        jnbNameAuthentication.setUpdateBy(SecurityUtils.getUserId().toString());
        return jnbNameAuthenticationMapper.updateJnbNameAuthentication(jnbNameAuthentication);
    }

    /**
     * 批量删除实名认证
     *
     * @param ids 需要删除的实名认证主键
     * @return 结果
     */
    @Override
    public int deleteJnbNameAuthenticationByIds(String[] ids) {
        return jnbNameAuthenticationMapper.deleteJnbNameAuthenticationByIds(ids);
    }

    /**
     * 删除实名认证信息
     *
     * @param id 实名认证主键
     * @return 结果
     */
    @Override
    public int deleteJnbNameAuthenticationById(String id) {
        return jnbNameAuthenticationMapper.deleteJnbNameAuthenticationById(id);
    }

    /*
    * 审核
    *
    * @author 韩福成
    * @date 2024/3/5 11:10
    */
    @Override
    public int through(JnbNameAuthentication jnbNameAuthentication) {
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String data = simpleDateFormat.format(jnbNameAuthentication.getCreateTime());
        Announcement announcement = new Announcement();
        announcement.setUserId(IdUtils.simpleUUID());
        announcement.setCreateBy(SecurityUtils.getUserId().toString());
        String type = DictUtils.getDictLabel("examine_state",jnbNameAuthentication.getStatus());
        announcement.setAnnouncementTitle(type+":[实名认证]");
        announcement.setAnnouncementBody("您在"+data+"发起的[实名认证]信息已["+type+"]");
        announcement.setAnnoType("jnb_name_authentication");
        announcement.setBindId(jnbNameAuthentication.getId());
        announcementService.insertAnnouncement(announcement);
        if (jnbNameAuthentication.getStatus().equals("1")){
            jnbNameAuthenticationMapper.updateWxUser(jnbNameAuthentication);
        }
        return jnbNameAuthenticationMapper.updateJnbNameAuthentication(jnbNameAuthentication);
    }

    /*
    * 小程序-按登录人获取实名认证信息
    *
    * @author 韩福成
    * @date 2024/3/6 14:44
    */
    @Override
    public JnbNameAuthentication getNameInfo(String userId) {
        return jnbNameAuthenticationMapper.getNameInfo(userId);
    }
}
