package com.sooka.jnb.my.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.DictUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.uuid.IdUtils;
import com.sooka.jnb.my.domain.Announcement;
import com.sooka.jnb.my.domain.JnbAuthenticationImg;
import com.sooka.jnb.my.domain.JnbOfficialAuthentication;
import com.sooka.jnb.my.mapper.JnbNameAuthenticationMapper;
import com.sooka.jnb.my.mapper.JnbOfficialAuthenticationMapper;
import com.sooka.jnb.my.service.IAnnouncementService;
import com.sooka.jnb.my.service.IJnbOfficialAuthenticationService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.text.SimpleDateFormat;
import java.util.List;

/**
 * 官方认证Service业务层处理
 *
 * @author 韩福成
 * @date 2024-03-02
 */
@Service
public class JnbOfficialAuthenticationServiceImpl implements IJnbOfficialAuthenticationService {
    @Autowired
    private JnbOfficialAuthenticationMapper jnbOfficialAuthenticationMapper;

    @Autowired
    private JnbNameAuthenticationMapper jnbNameAuthenticationMapper;

    @Autowired
    private IAnnouncementService announcementService;

    /**
     * 查询官方认证
     *
     * @param id 官方认证主键
     * @return 官方认证
     */
    @Override
    public JnbOfficialAuthentication selectJnbOfficialAuthenticationById(String id) {
        return jnbOfficialAuthenticationMapper.selectJnbOfficialAuthenticationById(id);
    }

    /**
     * 查询官方认证列表
     *
     * @param jnbOfficialAuthentication 官方认证
     * @return 官方认证
     */
    @Override
    public List<JnbOfficialAuthentication> selectJnbOfficialAuthenticationList(JnbOfficialAuthentication jnbOfficialAuthentication) {
        return jnbOfficialAuthenticationMapper.selectJnbOfficialAuthenticationList(jnbOfficialAuthentication);
    }

    /**
     * 新增官方认证
     *
     * @param jnbOfficialAuthentication 官方认证
     * @return 结果
     */
    @Override
    public int insertJnbOfficialAuthentication(JnbOfficialAuthentication jnbOfficialAuthentication) {
        jnbOfficialAuthentication.setId(IdUtils.simpleUUID());
        jnbOfficialAuthentication.setCreateBy(SecurityUtils.getUserId().toString());
        jnbOfficialAuthentication.setCreateTime(DateUtils.getNowDate());
        jnbOfficialAuthentication.setDelFlag("1");
        jnbOfficialAuthentication.setStatus("3");
        if (jnbOfficialAuthentication.getPath()!=null){
            String[] paths = jnbOfficialAuthentication.getPath().split(",");
            for (String path : paths) {
                JnbAuthenticationImg img = new JnbAuthenticationImg();
                img.setId(IdUtils.simpleUUID());
                img.setAuthenticationId(jnbOfficialAuthentication.getId());
                img.setPath(path);
                jnbNameAuthenticationMapper.insertJnbAuthenticationImg(img);
            }
        }

        return jnbOfficialAuthenticationMapper.insertJnbOfficialAuthentication(jnbOfficialAuthentication);
    }

    /**
     * 修改官方认证
     *
     * @param jnbOfficialAuthentication 官方认证
     * @return 结果
     */
    @Override
    public int updateJnbOfficialAuthentication(JnbOfficialAuthentication jnbOfficialAuthentication) {
        jnbOfficialAuthentication.setUpdateTime(DateUtils.getNowDate());
        jnbOfficialAuthentication.setUpdateBy(SecurityUtils.getUserId().toString());
        return jnbOfficialAuthenticationMapper.updateJnbOfficialAuthentication(jnbOfficialAuthentication);
    }

    /**
     * 批量删除官方认证
     *
     * @param ids 需要删除的官方认证主键
     * @return 结果
     */
    @Override
    public int deleteJnbOfficialAuthenticationByIds(String[] ids) {
        return jnbOfficialAuthenticationMapper.deleteJnbOfficialAuthenticationByIds(ids);
    }

    /**
     * 删除官方认证信息
     *
     * @param id 官方认证主键
     * @return 结果
     */
    @Override
    public int deleteJnbOfficialAuthenticationById(String id) {
        return jnbOfficialAuthenticationMapper.deleteJnbOfficialAuthenticationById(id);
    }

    /*
    * 审核官方认证
    *
    * @author 韩福成
    * @date 2024/3/5 13:56
    */
    @Override
    public int through(JnbOfficialAuthentication jnbOfficialAuthentication) {
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String data = simpleDateFormat.format(jnbOfficialAuthentication.getCreateTime());
        Announcement announcement = new Announcement();
        announcement.setUserId(IdUtils.simpleUUID());
        announcement.setCreateBy(SecurityUtils.getUserId().toString());
        String type = DictUtils.getDictLabel("examine_state",jnbOfficialAuthentication.getStatus());
        announcement.setAnnouncementTitle(type+":[官方认证]");
        announcement.setAnnouncementBody("您在"+data+"发起的[官方认证]信息已["+type+"]");
        announcement.setAnnoType("jnb_official_authentication");
        announcement.setBindId(jnbOfficialAuthentication.getId());
        announcementService.insertAnnouncement(announcement);
        return jnbOfficialAuthenticationMapper.updateJnbOfficialAuthentication(jnbOfficialAuthentication);
    }

    /*
    *小程序-按登录人获取官方认证信息
    *
    * @author 韩福成
    * @date 2024/3/6 16:22
    */
    @Override
    public JnbOfficialAuthentication getOfficialInfo(String userId) {
        return jnbOfficialAuthenticationMapper.getOfficialInfo(userId);
    }
}
