package com.sooka.jnb.my.service.impl;

import com.sooka.jnb.my.domain.ScoreOperate;
import com.sooka.jnb.my.mapper.ScoreMapper;
import com.sooka.jnb.my.service.IScoreService;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 积分操作
 *
 * @author LG
 * @date 2019-05-29 10:43
 */
@Service
public class ScoreServiceImpl implements IScoreService {

    private static final String ADD = "+";
    private static final String REDUCE = "-";

    @Resource
    private ScoreMapper scoreMapper;

    @Override
    @Transactional
    public int initScore(ScoreOperate score) {
        if (null == score.getCreateTime()) {
            score.setCreateTime(new Date());
        }
        score.setScoreOperate(ADD + score.getScoreNum());
        scoreMapper.initScore(score);
        return scoreMapper.insertScoreOperate(score);
    }

    @Override
    public ScoreOperate getScore(String userId) {
        return scoreMapper.getScore(userId);
    }

    @Override
    public List<ScoreOperate> getList(ScoreOperate score) {
        return scoreMapper.getList(score);
    }

    @Override
    public List<ScoreOperate> getScoreList(ScoreOperate score) {
        return scoreMapper.getScoreList(score);
    }

    @Override
    @Transactional
    public int addScore(ScoreOperate scoreOperate) {
        scoreMapper.addScore(scoreOperate);
        return this.insertScoreOperate(scoreOperate, ADD);
    }

    @Override
    @Transactional
    public int reduceScore(ScoreOperate scoreOperate) {
        scoreMapper.reduceScore(scoreOperate);
        return this.insertScoreOperate(scoreOperate, REDUCE);
    }

    /**
     * 插入积分操作记录
     *
     * @param scoreOperate 积分操作对象
     * @param operate      积分操作类型
     */
    private int insertScoreOperate(ScoreOperate scoreOperate, String operate) {
        scoreOperate.setScoreOperate(operate + scoreOperate.getScoreNum());
        Date date = new Date();
        scoreOperate.setCreateTime(date);
        scoreOperate.setUpdateTime(date);
        return scoreMapper.insertScoreOperate(scoreOperate);
    }

    @Override
    public boolean soleVerify(String userId) {
        Map<String, Long> resultMap = scoreMapper.soleVerify(userId);
        return resultMap.get("personSum") > 0;
    }

    @Override
    public int knowledgeWhetherToPay(String userId, String relevanceDataId) {
        return scoreMapper.knowledgeWhetherToPay(userId,relevanceDataId);
    }

    @Override
    public boolean verifyScore(ScoreOperate score) {
        return scoreMapper.getScore(score.getUserId()).getScoreNum() >= score.getScoreNum();
    }
}
