package com.sooka.jnb.quotations.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.sooka.jnb.highServer.mapper.JnbHighServerImgMapper;
import com.sooka.jnb.my.domain.Announcement;
import com.sooka.jnb.my.service.IAnnouncementService;
import com.sooka.jnb.quotations.domain.JnbQuotations;
import com.sooka.jnb.quotations.mapper.JnbQuotationsMapper;
import com.sooka.jnb.quotations.service.IJnbQuotationsService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.util.Arrays;
import java.util.Date;
import java.util.List;
import java.util.Objects;


/**
 * 行情Service业务层处理
 *
 * @author ruoyi
 * @date 2024-03-01
 */
@Service
public class JnbQuotationsServiceImpl implements IJnbQuotationsService {

    @Resource
    private JnbQuotationsMapper jnbQuotationsMapper;

    @Resource
    private IAnnouncementService announcementService;


    /**
     * 查询行情
     *
     * @param id 行情主键
     * @return 行情
     */
    @Override
    public JnbQuotations selectJnbQuotationsById(Long id) {
        JnbQuotations jnbQuotations = jnbQuotationsMapper.selectJnbQuotationsById(id);
        return jnbQuotations;
    }

    /**
     * 查询行情列表
     *
     * @param jnbQuotations 行情
     * @return 行情
     */
    @Override
    public List<JnbQuotations> selectJnbQuotationsList(JnbQuotations jnbQuotations) {
        List<JnbQuotations> list = jnbQuotationsMapper.selectJnbQuotationsList(jnbQuotations);
        for (JnbQuotations quotations : list) {
            //如果url不为空,则将url转换为List,并且储存在list中返回
            if (!Objects.isNull(quotations.getUrl())) {
                List<String> list1 = Arrays.asList(quotations.getUrl().split(","));
                jnbQuotations.setUrlArray(list1);
            }
        }
        return list;
    }

    /**
     * 新增行情
     *
     * @param jnbQuotations 行情
     * @return 结果
     */
    @Override
    public int insertJnbQuotations(JnbQuotations jnbQuotations) {
        int i = jnbQuotationsMapper.selectCount(jnbQuotations);
        if (i > 0) {
            return -1;
        }
        jnbQuotations.setCreateBy(SecurityUtils.getUserId().toString());
        jnbQuotations.setCreateTime(DateUtils.getNowDate());
        int insert = jnbQuotationsMapper.insertJnbQuotations(jnbQuotations);
        return insert;
    }

    /**
     * 修改行情
     *
     * @param jnbQuotations 行情
     * @return 结果
     */
    @Override
    public int updateJnbQuotations(JnbQuotations jnbQuotations) {
        jnbQuotations.setUpdateBy(SecurityUtils.getUsername());
        jnbQuotations.setUpdateTime(DateUtils.getNowDate());
        return jnbQuotationsMapper.updateJnbQuotations(jnbQuotations);
    }

    /**
     * 批量删除行情
     *
     * @param ids 需要删除的行情主键
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int deleteJnbQuotationsByIds(Long[] ids) {
        int i = jnbQuotationsMapper.deleteJnbQuotationsByIds(ids);
        return i;
    }

    /**
     * 修改审核状态
     */
    @Override
    public int updateByStatusAndId(JnbQuotations jnbQuotations) {
        int i = jnbQuotationsMapper.updateByStatusAndId(jnbQuotations);
        if (i>0) {
            announcementService.insertAnnouncement(fromate(jnbQuotations.getId().toString(),jnbQuotations.getStatus(), jnbQuotations.getProductName(), jnbQuotations.getCreateBy(),jnbQuotations.getCreateTime()));
        }
        return i;

    }

    public Announcement fromate(String bindId,String status,String title,String id,Date createTime) {
        Announcement announcement = new Announcement();
        SimpleDateFormat simpleDateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        String data = simpleDateFormat.format(createTime);
        if (Objects.equals(status, "1")) {
            announcement.setAnnouncementTitle("审核通过:[行情]" + title);
            announcement.setAnnouncementBody("您在" + data + "发起的行情信息已审核通过，请查看");
            announcement.setValidityStartTime(new Date());
            announcement.setUserId(id);
            announcement.setAnnoType("jnb_quotations");
            announcement.setBindId(bindId);
            announcement.setCreateBy(SecurityUtils.getUserId().toString());
            return announcement;
        } else {
            announcement.setAnnouncementTitle("审核拒绝:[行情]" + title);
            announcement.setAnnouncementBody("您在" + data + "发起的行情信息已审核被拒绝，请查看");
            announcement.setValidityStartTime(new Date());
            announcement.setUserId(id);
            announcement.setBindId(bindId);
            announcement.setAnnoType("jnb_quotations");
            announcement.setCreateBy(SecurityUtils.getUserId().toString());
            return announcement;
        }
    }
}
